@@ -38,6 +38,7 @@
 
 // FILE_IS.C
 // 
+gboolean	FileIs_m4a( gchar *namefile );
 gboolean	FileIs_wavpack (gchar *namefile);
 gboolean	FileIs_wav (gchar *namefile);
 gboolean	FileIs_shn (gchar *namefile);
@@ -51,6 +52,9 @@ gboolean	FileIs_ape (gchar *namefile);
 gboolean	FileIs_aiff (gchar *namefile);
 gboolean	FileIs_dts (gchar *namefile);
 gboolean	FileIs_g_str_has_suffix (gchar *NameSong, gchar *Suffixe);
+gboolean	FileIs_png( gchar *namefile );
+gboolean	FileIs_jpg( gchar *namefile );
+gboolean	FileIs_image( gchar *PathNameFile );
 
 // LIB.C
 // 
