@@ -34,8 +34,8 @@
  */
 
 
-#ifndef __alsa_audio_h__
-#define __alsa_audio_h__ 1
+#ifndef alsa_audio_h
+#define alsa_audio_h 1
 
 #include <gtk/gtk.h>
 #include <alsa/asoundlib.h>
