@@ -25,8 +25,8 @@
  */
 
 
-#ifndef __play_alsa_h__
-#define __play_alsa_h__ 1
+#ifndef play_alsa_h
+#define play_alsa_h 1
 
 void		AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncSetValueTime, void *p_FuncIconeStop);
 void		AlsaPlay_fseek (gdouble p_NewPosInPercent);
