@@ -39,7 +39,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -78,7 +78,6 @@
 #include "notify_send.h"
 #include "win_scan.h"
 #include "popup_systray.h"
-#include "cd_audio.h"
 #include "cd_audio_extract.h"
 
 
@@ -981,15 +980,20 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 	PRINT("DEBUT THREAD CONVERSIONS");
 				
 	ListOne = g_list_first (EnteteCD.GList_Audio_cd);
-	while (FALSE == conv.bool_stop && ListOne) {
+	while( FALSE == conv.bool_stop && NULL != ListOne ) {
+		
+		sleep( 0 );
+		if( TRUE == conv.bool_stop ) {
+			conv.bool_stop = TRUE;
+			Audio->Bool_Delette_Mp3 = TRUE;
+			Audio->Bool_Delette_Ogg = TRUE;
+			break;
+		}
 		
 		if (NULL == (Audio = (CD_AUDIO *)ListOne->data)) {
 			ListOne = g_list_next(ListOne);
 			continue;
 		}
-		// if (TRUE == conv.bool_thread_extract) {
-		// 	continue;
-		// }
 		
 		if (TRUE == Audio->EtatNormalise && VarCdExtract.ComboNumActive == 1) {
 			/*  PEAK
@@ -1660,9 +1664,9 @@ static gint cdaudioextract_timeout (gpointer data)
 		WindScan_close ();
 		
 		if (FALSE == conv.bool_stop) {
-			NotifySend_msg (_("XCFA: Extraction CD"), _("Ok"));
+			NotifySend_msg (_("XCFA: Extraction CD"), _("Ok"), conv.bool_stop);
 		} else {
-			NotifySend_msg (_("XCFA: Extraction CD"), _("Arret par l'utilisateur"));
+			NotifySend_msg (_("XCFA: Extraction CD"), _("Arret par l'utilisateur"), conv.bool_stop);
 		}
 	}
 	return (TRUE);
@@ -1934,6 +1938,11 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	else if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_extract_with_cdda2wav)) == TRUE)
 		Config.ExtractCdWith = EXTRACT_WITH_CDDA2WAV;
 
+	if( conv.bool_thread_conv == TRUE || conv.bool_thread_extract == TRUE ) {
+		PRINT("conv.bool_thread_conv == TRUE || conv.bool_thread_extract == TRUE  -> RETURN" );
+		return;
+	}
+	
 	conv_reset_struct (WindScan_close_request);
  	VarCdExtract.BoolFormatUnique = FALSE;
  	if (VarCdExtract.NameFileFormatUnique != NULL)
@@ -1966,13 +1975,10 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 
 	PopupSystray_set_BoolMainAction (TRUE);
 	
+	conv.bool_thread_conv = TRUE;
  	pthread_create (&nmr_tid, NULL ,(void *)cdaudioextract_thread_conversion_from_cd, (void *)NULL);
-	// pthread_detach (nmr_tid);
-
 	conv.bool_thread_extract = TRUE;
  	pthread_create (&nmr_tid, NULL ,(void *)cdaudioextract_thread_extraction_from_cd, (void *)NULL);
-	// pthread_detach (nmr_tid);
-
 	PRINT("DEBUT TIMEOUT");
 	conv.handler_timeout_conv = gtk_timeout_add (50, cdaudioextract_timeout, 0);
 }
