@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -53,10 +53,11 @@
 
 #include "global.h"
 #include "cd_audio.h"
-#include "cd_cddb.h"
 #include "get_info.h"
 #include "cd_cue.h"
 #include "configuser.h"
+#include "poche.h"
+#include "cd_cddb.h"
 
 
 
@@ -589,18 +590,25 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 {
 	gint		NumList;
 	CD_AUDIO	*Audio = NULL;
+	GString 	*gstr_buffer_title             = g_string_new (NULL);
+	GString 	*gstr_buffer_title_time        = g_string_new (NULL);
+	GString 	*gstr_buffer_artist_title_time = g_string_new (NULL);
 	
 	// TODO: DEBUG: manuker: http://forum.ubuntu-fr.org/viewtopic.php?pid=4631891#p4631891
 	PRINT_FUNC_LF();
 
 	// REMOVE DATAS entete
 	CdCddb_init_entete_cd();
+	poche_remove_view();
 	
 	EnteteCD.Message = g_strdup( VarCddb . Message );
 	
 	// 
 	switch( p_etat ) {
 	case CDDB_RET_OK :		// OK
+		
+		view.TitleCD = g_strdup_printf( "%s  -  %s", VarCddb . Artiste, VarCddb . TitleCD );
+		
 		EnteteCD.TitleCD     = g_strdup_printf( "%s  -  %s", VarCddb . Artiste, VarCddb . TitleCD );
 		EnteteCD.Artiste     = g_strdup( VarCddb . TitleCD );
 		EnteteCD.TotalTracks = VarCddb . TotalTracks;
@@ -611,13 +619,10 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 		EnteteCD.StrDureeCd  = g_strdup( VarCddb . StrDureeCd );
 		break;
 	case CDDB_RET_NO_CONNECT :	// PAS DE CONNEXION WEB
-		EnteteCD.TitleCD     = g_strdup( "Track" );
-		EnteteCD.Title       = g_strdup( "Track" );
-		EnteteCD.Artiste     = g_strdup( "Track" );
-		EnteteCD.TotalTracks = VarCddb . TotalTracks;
-		EnteteCD.StrDureeCd  = g_strdup( VarCddb . StrDureeCd );
-		break;
 	case CDDB_RET_NO_BASE :		// PAS DE BASE POUR CE DISQUE
+		
+		view.TitleCD = g_strdup( "Track" );
+		
 		EnteteCD.TitleCD     = g_strdup( "Track" );
 		EnteteCD.Title       = g_strdup( "Track" );
 		EnteteCD.Artiste     = g_strdup( "Track" );
@@ -676,9 +681,33 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 		Audio->Duree			= g_strdup( VarCddb . VarStructCddb [ NumList ] . Duree );
 		Audio->NameSong			= g_strdup_printf ("Track_%02d", NumList + 1);
 		
+		// view.TitleCD = g_strdup ( VarCddb . TitleCD );
+		view.Buffer_none = 
+		view.Buffer_title = 
+		view.Buffer_title_time = 
+		view.Buffer_artist_title_time = NULL;
+		
 		// OK
 		if( CDDB_RET_OK == p_etat ) {
 			
+			g_print( "TITLE_CD: %s  ", VarCddb . TitleCD );
+			g_print( "TRACK: %d  ", NumList + 1 );
+			g_print( "DUREE: %s  ", VarCddb . VarStructCddb [ NumList ] . Duree );
+			g_print( "ARTIST: %s  ", VarCddb . VarStructCddb [ NumList ] . Artist );
+			g_print( "TITLE: %s  ", VarCddb . VarStructCddb [ NumList ] . Title );
+			g_print( "YEAR: %d  ", VarCddb . NumYear );
+			g_print( "\n" );
+		
+			// TITRE
+			g_string_append_printf( gstr_buffer_title, "%s\n", VarCddb . VarStructCddb [ NumList ] . Title );
+			// TITRE - TEMPS
+			g_string_append_printf( gstr_buffer_title_time, "%s  ][  ", VarCddb . VarStructCddb [ NumList ] . Title );
+			g_string_append_printf( gstr_buffer_title_time, "%s\n", VarCddb . VarStructCddb [ NumList ] . Duree );
+			// ARTISTE - TITRE - TEMPS
+			g_string_append_printf( gstr_buffer_artist_title_time, "%s  -  ", VarCddb . VarStructCddb [ NumList ] . Artist );
+			g_string_append_printf( gstr_buffer_artist_title_time, "%s  ][  ", VarCddb . VarStructCddb [ NumList ] . Title );
+			g_string_append_printf( gstr_buffer_artist_title_time, "%s\n", VarCddb . VarStructCddb [ NumList ] . Duree );
+
 			if( NULL != VarCddb . VarStructCddb [ NumList ] . Title ) {
 				g_free( Audio->NameSong );	Audio->NameSong = NULL;
 				Audio->NameSong = g_strdup( VarCddb . VarStructCddb [ NumList ] . Title );
@@ -702,6 +731,16 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 		// PAS DE CONNEXION WEB
 		else if( CDDB_RET_NO_CONNECT == p_etat ) {
 			
+			// TITRE
+			g_string_append_printf( gstr_buffer_title, "Track_%02d\n", NumList +1 );
+			// TITRE - TEMPS
+			g_string_append_printf( gstr_buffer_title_time, "Track_%02d  ][  ", NumList +1 );
+			g_string_append_printf( gstr_buffer_title_time, "%s\n", VarCddb . VarStructCddb [ NumList ] . Duree );
+			// ARTISTE - TITRE - TEMPS
+			// g_string_append_printf( gstr_buffer_artist_title_time, "%s  -  ", VarCddb . VarStructCddb [ NumList ] . Artist );
+			g_string_append_printf( gstr_buffer_artist_title_time, "Track_%02d  ][  ", NumList +1 );
+			g_string_append_printf( gstr_buffer_artist_title_time, "%s\n", VarCddb . VarStructCddb [ NumList ] . Duree );
+
 			Audio->tags = (TAGS *)tags_remove (Audio->tags);
 			Audio->tags = (TAGS *)tags_alloc (TRUE);
 			
@@ -721,6 +760,16 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 		// PAS DE BASE POUR CE DISQUE
 		else if( CDDB_RET_NO_BASE == p_etat ) {
 				
+			// TITRE
+			g_string_append_printf( gstr_buffer_title, "Track_%02d\n", NumList +1 );
+			// TITRE - TEMPS
+			g_string_append_printf( gstr_buffer_title_time, "Track_%02d  ][  ", NumList +1 );
+			g_string_append_printf( gstr_buffer_title_time, "%s\n", VarCddb . VarStructCddb [ NumList ] . Duree );
+			// ARTISTE - TITRE - TEMPS
+			// g_string_append_printf( gstr_buffer_artist_title_time, "%s  -  ", VarCddb . VarStructCddb [ NumList ] . Artist );
+			g_string_append_printf( gstr_buffer_artist_title_time, "Track_%02d  ][  ", NumList +1 );
+			g_string_append_printf( gstr_buffer_artist_title_time, "%s\n", VarCddb . VarStructCddb [ NumList ] . Duree );
+
 			Audio->tags = (TAGS *)tags_remove (Audio->tags);
 			Audio->tags = (TAGS *)tags_alloc (TRUE);
 			
@@ -738,7 +787,19 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 		}
 		
 		EnteteCD.GList_Audio_cd = g_list_append (EnteteCD.GList_Audio_cd, (CD_AUDIO *)Audio);
-
+	}
+	if( CDDB_RET_OK == p_etat || CDDB_RET_NO_CONNECT == p_etat || CDDB_RET_NO_BASE == p_etat ) {
+		
+		view.Buffer_none = g_strdup( " " );
+		
+		view.Buffer_title = g_strdup( gstr_buffer_title->str );
+		g_string_free( gstr_buffer_title, TRUE );
+		
+		view.Buffer_title_time = g_strdup( gstr_buffer_title_time->str );
+		g_string_free( gstr_buffer_title_time, TRUE );
+		
+		view.Buffer_artist_title_time = g_strdup( gstr_buffer_artist_title_time->str );
+		g_string_free( gstr_buffer_artist_title_time, TRUE );
 	}
 }
 // 
@@ -810,6 +871,21 @@ gboolean CdCddb_test_access_web (void)
 
 
 
+void CdCddb_set_combobox_choice( gint p_activate )
+{
+	if( p_activate > -1 ) {
+		view.BoolAccessChanged = FALSE;
+		gtk_combo_box_set_active( GTK_COMBO_BOX (view.AdrComboBoxChoice), p_activate );
+		view.BoolAccessChanged = TRUE;
+	}
+}
+gchar *CdCddb_get_title_cd( void )
+{
+	return( view.TitleCD );
+}
+
+
+
 
 
 
