@@ -48,10 +48,20 @@ typedef enum {
 	CONNECT_IS_NO_MATCH_FOUND
 } ETAT_CONNECT;
 
+typedef enum {
+	_CDDB_BUFFER_NONE_ = 0,
+	_CDDB_BUFFER_TITLE_,
+	_CDDB_BUFFER_TITLE_TIME_,
+	_CDDB_BUFFER_ARTIST_TITLE_TIME_
+} TYPE_CDDB_BUFFER;
+
 gboolean	CdCddb_read_toc (void);
 void		CdCddb_set_bool_cancel_cddb (gboolean FLAG);
 gboolean	CdCddb_get_bool_cancel_cddb (void);
 gboolean	CdCddb_test_access_web (void);
+void		CdCddb_set_combobox_choice( gint p_activate );
+gchar		*CdCddb_get_title_cd( void );
+void		CdCddb_reffresh_list_cd( gint p_Choice );
 
 #endif
 
