@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -456,9 +456,9 @@ void cdcue_write_cue_ok_partiel (void)
 // 
 void cdcue_write_cue (void)
 {
-	gchar	*PathName = NULL;
-	gchar	*Str = NULL;
-	gchar	*Ptr = NULL;
+	// gchar	*PathName = NULL;
+	// gchar	*Str = NULL;
+	// ggchar	*Ptr = NULL;
 	
 	if (BaseIoctl.Cue == NULL) return;
 	
@@ -469,40 +469,39 @@ void cdcue_write_cue (void)
 	case TYPE_CUE_FILE :
 		if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_creation_fichier_cue"))) == TRUE) {
 			
-			/*if (libutils_test_file_exist (PathName) == TRUE) {*/
+			/*
 			if (libutils_test_file_exist (BaseIoctl.PathNameDestFileCue) == TRUE) {
 				
 				Str = g_strdup_printf (_("<b>\nLe fichier existe:\n%s       \nVoulez vous le remplacer  ?       \n</b>"), BaseIoctl.PathNameDestFileCue);
-				/*
 				windchoice_open (
 					_("Le fichier existe"),
 					Str,
 					TRUE,
 					cdcue_write_cue_ok_partiel
 					);
-				*/
 				break;
 			}
+			*/
 			cdcue_write_cue_ok_partiel ();
 		}
 		break;
 		
 	case TYPE_CUE_CD :
+		/*
 		PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config.PathDestinationCD, BaseIoctl.Performer);
 		
 		if (libutils_test_file_exist (PathName) == TRUE) {
 			
 			Str = g_strdup_printf (_("<b>\nLe fichier existe:\n%s       \nVoulez vous le remplacer  ?       \n</b>"), PathName);
-			/*
 			windchoice_open (
 				_("Le fichier existe"),
 				Str,
 				TRUE,
 				cdcue_write_cue_ok
 				);
-			*/
 			break;
 		}
+		*/
 		cdcue_write_cue_ok ();
 		break;
 	}
@@ -510,6 +509,7 @@ void cdcue_write_cue (void)
 	/* FIN de creation CUE-FILE */
 	var_cd.TypeCreateCue = TYPE_CUE_NONE;
 	
+	/*
 	if (PathName != NULL) {
 		g_free (PathName);
 		PathName = NULL;
@@ -519,6 +519,7 @@ void cdcue_write_cue (void)
 		Str = NULL;
 	}
 	Ptr = NULL;
+	*/
 }
 // 
 // 
