@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -81,7 +81,6 @@ VAR_CONFIG Config = {
 	0,		// NotebookGeneral
 	0,		// NotebookExpanderCd
 	0,		// NotebookFile
-	0,		// NotebookPochette
 	0,		// NotebookOptions
 	0,		// NotebookAppExterns
 	0,		// ExtractCdWith = EXTRACT_WITH_CDPARANOIA = 0
@@ -142,7 +141,16 @@ VAR_CONFIG Config = {
 	NULL,		// StringPosFieldsName		POS NAME OF DVD,CD,FILES: 0 = LEFT, 1 = CENTER, 2 = RIGHT
 	0,		// NumSelectComboBoxDvd
 	0,		// NumSelectComboBoxCd
-	NULL		// entry_cddp_server
+	NULL,		// entry_cddp_server
+	
+	NULL,		// NameImg
+	NULL,		// PathLoadImg
+	NULL,		// PathSaveImg;
+	NULL,		// PathPochette
+
+	FALSE,		// gboolean	BoolCheckbuttonEndOfConvert
+	NULL,		// gchar	*PathMusicFileEndOfConvert
+	NULL		// gchar	*FileMusicFileEndOfConvert
 };
 
 
@@ -212,7 +220,10 @@ gboolean config_read_value_str (gchar *p_Buf, gchar *p_Search, gchar **p_ValueSt
 			return (TRUE);	
 		}
 	}
-	return (FALSE);	
+	else {
+		// *p_ValueStr = g_strdup( "" );
+	}
+	return (FALSE);
 }
 // 
 // 
@@ -330,7 +341,6 @@ void config_read (void)
 		if (FALSE == config_read_value_atoi (buf, "NOTEBOOK_GENERAL",			&Config.NotebookGeneral, 		-1,	-1))
 		if (FALSE == config_read_value_atoi (buf, "NOTEBOOK_EXPANDER_CD",		&Config.NotebookExpanderCd,		-1,	-1))
 		if (FALSE == config_read_value_atoi (buf, "NOTEBOOK_FILE",			&Config.NotebookFile,			-1,	-1))
-		if (FALSE == config_read_value_atoi (buf, "NOTEBOOK_POCHETTE",			&Config.NotebookPochette,		-1,	-1))
 		if (FALSE == config_read_value_atoi (buf, "NOTEBOOK_OPTIONS",			&Config.NotebookOptions,  		-1,	-1))
 		if (FALSE == config_read_value_atoi (buf, "NOTEBOOK_APP_EXTERNS",		&Config.NotebookAppExterns,  		-1,	-1))
 		if (FALSE == config_read_value_atoi (buf, "EXTRACT_CD_WITH",			&Config.ExtractCdWith,    		EXTRACT_WITH_CDPARANOIA,  EXTRACT_WITH_CDDA2WAV))
@@ -380,6 +390,10 @@ void config_read (void)
 		if (FALSE == config_read_value_bool (buf, "TAGS_YEAR",				&Config.BoolYearTag))
 		if (FALSE == config_read_value_bool (buf, "TAGS_COMMENT",			&Config.BoolCommentTag))
 		if (FALSE == config_read_value_bool (buf, "BOOL_ETAT_EXPANDER_CD",		&Config.BoolEtatExpanderCd))
+		// 
+		// 
+		if (FALSE == config_read_value_bool (buf, "BOOL_PLAY_MUSIC_END_CONVERT",	&Config.BoolCheckbuttonEndOfConvert ))
+	
 		
 		// READ PATH
 		// 
@@ -401,7 +415,13 @@ void config_read (void)
 		if (FALSE == config_read_value_path (buf, "PATH_LOAD_FILE_TAGS",		&Config.PathLoadFileTags,		NULL))
 		if (FALSE == config_read_value_path (buf, "PATH_DEST_SPLIT",			&Config.PathDestinationSplit,		NULL))
 		if (FALSE == config_read_value_path (buf, "PATH_LOAD_SPLIT",			&Config.PathLoadSplit,			NULL))
-
+		if (FALSE == config_read_value_path (buf, "PATH_LOAD_IMG",			&Config.PathLoadImg,			NULL))
+		if (FALSE == config_read_value_path (buf, "PATH_SAVE_IMG",			&Config.PathSaveImg,			NULL))
+		//
+		//
+		if (FALSE == config_read_value_path (buf, "PATH_MUSIC_END_CONVERT",		&Config.PathMusicFileEndOfConvert,	NULL ))
+		
+		
 		// READ STRING
 		// 
 		if (FALSE == config_read_value_str (buf, "STRING_EXPANDER_LAME",		&Config.StringExpanderLame))
@@ -421,7 +441,11 @@ void config_read (void)
 		if (FALSE == config_read_value_str (buf, "STRING_PARAM_NAME_LECTEUR_AUDIO",	&Config.StringParamNameLecteurAudio))
 		if (FALSE == config_read_value_str (buf, "STRING_BOOL_FIELD_IS_VISIBLE",	&Config.StringBoolFieldsIsVisible))
 		if (FALSE == config_read_value_str (buf, "STRING_POS_FIELD_IS_NAME",		&Config.StringPosFieldsName))
-		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_SERVER",		&Config.entry_cddp_server));
+		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_SERVER",		&Config.entry_cddp_server))
+		if (FALSE == config_read_value_str (buf, "NAME_IMG",				&Config.NameImg))
+		//
+		//
+		if (FALSE == config_read_value_str (buf, "FILE_NAME_MUSIC_END_CONVERT",		&Config.FileMusicFileEndOfConvert ));
 		
 		buf [ 0 ] = '\0';
 	}
@@ -446,6 +470,9 @@ void config_read (void)
 	config_verif_path (&Config.PathDestinationSplit,	NULL);
 	config_verif_path (&Config.PathLoadSplit,		NULL);
 
+	config_verif_path (&Config.PathLoadImg,			NULL);
+	config_verif_path (&Config.PathSaveImg,			NULL);
+	config_verif_path( &Config.PathMusicFileEndOfConvert,	NULL );
 }
 //  SAUVEGARDE DU FICHIER DE CONFIGURATION
 // 
@@ -497,7 +524,6 @@ void config_save (void)
 		fprintf (fp, "NOTEBOOK_GENERAL                    = %d\n", Config.NotebookGeneral);
 		fprintf (fp, "NOTEBOOK_EXPANDER_CD                = %d\n", Config.NotebookExpanderCd);
 		fprintf (fp, "NOTEBOOK_FILE                       = %d\n", Config.NotebookFile);
-		fprintf (fp, "NOTEBOOK_POCHETTE                   = %d\n", Config.NotebookPochette);
 		fprintf (fp, "NOTEBOOK_OPTIONS                    = %d\n", Config.NotebookOptions);
 		fprintf (fp, "NOTEBOOK_APP_EXTERNS                = %d\n", Config.NotebookAppExterns);
 		
@@ -597,6 +623,14 @@ void config_save (void)
 		
 		fprintf (fp, "NUM_SELECT_COMBOBOX_DVD             = %d\n", Config.NumSelectComboBoxDvd);
 		fprintf (fp, "NUM_SELECT_COMBOBOX_CD              = %d\n", Config.NumSelectComboBoxCd);
+
+		fprintf (fp, "NAME_IMG                            = %s\n", Config.NameImg != NULL ? Config.NameImg : "" );
+		fprintf (fp, "PATH_LOAD_IMG                       = %s\n", Config.PathLoadImg != NULL ? Config.PathLoadImg : "" );
+		fprintf (fp, "PATH_SAVE_IMG                       = %s\n", Config.PathSaveImg != NULL ? Config.PathSaveImg : "" );
+
+		fprintf (fp, "BOOL_PLAY_MUSIC_END_CONVERT         = %s\n", Config.BoolCheckbuttonEndOfConvert == TRUE ? "TRUE" : "FALSE");
+		fprintf (fp, "PATH_MUSIC_END_CONVERT              = %s\n", Config.PathMusicFileEndOfConvert != NULL ? Config.PathMusicFileEndOfConvert : "" );
+		fprintf (fp, "FILE_NAME_MUSIC_END_CONVERT         = %s\n", Config.FileMusicFileEndOfConvert != NULL ? Config.FileMusicFileEndOfConvert : "" );
 		
 		// TODO: RESERVED
 		// g_sprintf( String, "%08lx", ret );
@@ -648,5 +682,12 @@ void config_remove (void)
 	g_free (Config.StringBoolFieldsIsVisible);	Config.StringBoolFieldsIsVisible = NULL;
 	g_free (Config.StringPosFieldsName);		Config.StringPosFieldsName = NULL;
 	g_free (Config.entry_cddp_server);		Config.entry_cddp_server = NULL;
+	
+	g_free (Config.NameImg);			Config.NameImg = NULL;
+	g_free (Config.PathLoadImg);			Config.PathLoadImg = NULL;
+	g_free (Config.PathSaveImg);			Config.PathSaveImg = NULL;
+
+	g_free( Config.PathMusicFileEndOfConvert );	Config.PathMusicFileEndOfConvert  = NULL;	
+	g_free( Config.FileMusicFileEndOfConvert );	Config.FileMusicFileEndOfConvert = NULL;
 }
 
