@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -69,15 +69,14 @@ extern int kill (pid_t pid, int sig);
 #define CONV_MAX_CARS 1024
 #define CONV_MAX_VALUE_PERCENT 0.978597
 
-CONV conv = { FALSE }; /* conv.BoolUsed = FALSE */
-
+CONV conv;
 
 /*
 *---------------------------------------------------------------------------
 * STOP THREAD AND TIMEOUT
 *---------------------------------------------------------------------------
 */
-
+/*
 void conv_print (void)
 {
 	g_print("\tconv.encode_completed->%d  conv.total_convert->%d\n", conv.encode_completed, conv.total_convert);
@@ -87,6 +86,7 @@ void conv_print (void)
 	g_print("\tconv.conversion_percent = %f\n", conv.conversion_percent);
 	g_print("\n");
 }
+*/
 void conv_inc_rip_completed (void)
 {
 	if (conv.rip_completed < conv.total_rip) {
