@@ -25,10 +25,11 @@
  */
 
 
-#ifndef __cursor_h__
-#define __cursor_h__ 1
+#ifndef cursor_h
+#define cursor_h 1
 
 
+void	 cursor_set_clear (void);
 void	 cursor_set_hand (void);
 void     cursor_set_saisie (void);
 void     cursor_set_gauche_droite (void);
