@@ -28,7 +28,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -103,7 +103,8 @@ void dragndrop_list_drag_data (GtkWidget *widget, gchar *string)
 	    widget != var_file_wav.Adr_TreeView &&
 	    widget != var_file_mp3ogg.Adr_TreeView &&
 	    widget != var_file_tags.Adr_TreeView &&
-	    widget != poche.Adr_viewport_image_preview &&
+	    widget != view.Adr_viewport_image_preview &&
+	    widget != view.AdrDrawingarea &&
 	    widget != VarSplit.AdrWidgetSpectre) {
 		PRINT("ERREUR DRAG N DROP : WIDGET(dragndrop_list_drag_data) INCONNU --> RETOUR\n");
 		return;
@@ -148,15 +149,22 @@ void dragndrop_list_drag_data (GtkWidget *widget, gchar *string)
 			
 			fileanalyze_add_file_to_treeview (_PATH_LOAD_FILE_TAGS_, List);
 		}
-		else if (widget == poche.Adr_viewport_image_preview) {
-			
-			pochedir_add_img_file (List);
-		}
 		else if (widget == VarSplit.AdrWidgetSpectre) {
 			
 			split_load_from_dnd (List);
 		}
 		
+		else if( widget == view.Adr_viewport_image_preview ) {
+			
+			PRINT("FROM widget == view.Adr_viewport_image_preview\n");
+			pochedir_add_img_file (List);
+		}
+		else if( widget == view.AdrDrawingarea ) {
+			
+			PRINT("FROM widget == view.AdrDrawingarea");
+			poche_add_img_file_to_Drawingarea (List);
+		}
+		
 		g_slist_free (List);
 		List = NULL;
 	}
