@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -790,7 +790,7 @@ gboolean dvd_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 	gboolean            BoolSelectColNormalise = FALSE;	
 	gboolean            BoolSelectColNom = FALSE;
 
-	if (keys.eventkey == GDK_KEY_PRESS) {
+	if (keys.keyval == GDK_KEY_PRESS) {
 		return (FALSE);
 	}
 
