@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright :( C) 2003 - 2011 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -51,9 +51,6 @@ typedef struct {
 */
 
 typedef struct {
-	// gdouble			 Value;					// 
-	// gdouble			 ValueMarkA;				// 
-	// gdouble			 ValueMarkB;				// 
 	guint			 SecTime;				// 
 } VALUE_MARK;
 
@@ -82,7 +79,7 @@ typedef struct {
 	gchar			*time;					//  Temps d'ecoute
 	guint			 SecTime;				//  Temps d'ecoute en secondes
 	VALUE_MARK		 ValueMark;				//  
-	gchar			*hertz;					// Taux d'échantillonnage en hertz (qualité du son)
+	gchar			*hertz;					// Taux d'échantillonnage en hertz( qualité du son)
 	gchar			*voie;					// 1, 2, 4, 6
 	gchar			*bits;					// 8, 16, ,24, 32 ou 64
 	gchar			*NewHertz;				// Nouvelle valeur
@@ -186,30 +183,23 @@ typedef struct {
 */
 
 typedef struct {
-
 	gint			type;					// 
 	gint			debit[4];				// 
 	gint			mode[4];				// 
 	gboolean		BoolChanged;				// 
-
 } TYPE_MP3OGG;
 
 typedef struct {
-
 	gboolean		 Bool_Conv;				// TRUE si conversion
-
 	gchar			*New_src;				// Temporaire: Pathname
 	gchar			*destwav;				// Temporaire: Pathname
 	gchar			*destsox;				// Temporaire: Pathname
 	gchar			*destmp3;				// Temporaire: Pathname
 	gchar			*destogg;				// Temporaire: Pathname
 	gchar			*destfile;				// Destination du fichier apres rectification
-
 	gchar			*Bitrate;				// Le bitrate actuel
-	
 	TYPE_MP3OGG		Lame;					// 
 	TYPE_MP3OGG		Oggenc;					// 
-	
 } CONV_FIC_MP3OGG;
 
 /*
@@ -219,13 +209,11 @@ typedef struct {
 */
 
 typedef struct {
-
 	gchar			*Path;					// Path du fichier source
 	gchar			*TmpSrc;				// $TMP/original
 	gchar			*TmpDest;				// $TMP/modifie
 	gchar			*TmpMplayer;				// $TMP/
 	gchar			*NameDest;				// Copie vers la destination
-
 } CONV_FIC_WAV;
 
 /*
@@ -235,16 +223,15 @@ typedef struct {
 */
 
 typedef enum {
-
 	FILE_IS_NONE = 0,
 	FILE_IS_FLAC,
 	FILE_IS_WAV,
 	FILE_IS_MP3,
 	FILE_IS_OGG,
 	/* Les fichiers au format AAC, portant l'extension
-		.mp4 (pour MPEG-4),
-	   	.m4a (pour MPEG-4 Audio)
-	   	.m4p (pour MPEG-4 Protégé),
+		.mp4( pour MPEG-4),
+	   	.m4a( pour MPEG-4 Audio)
+	   	.m4p( pour MPEG-4 Protégé),
 	   sont globalement plus petits que les fichiers au format MP3. */
 	FILE_IS_M4A,
 	FILE_IS_AAC,
@@ -258,48 +245,33 @@ typedef enum {
 	FILE_IS_WAVPACK,
 	FILE_IS_WAVPACK_MD5,
 	FILE_IS_AC3,
-	FILE_IS_CUE,
-	
 	FILE_TO_NORMALISE,
 	FILE_TO_NORMALISE_COLLECTIF,
-	FILE_TO_REPLAYGAIN,
-	FILE_IS_IMG,
-	FILE_IS_HTML,
-	FILE_IS_TXT,
-	FILE_IS_XCFA_GEN_CONF
-
+	FILE_TO_REPLAYGAIN
 } TYPE_FILE_IS;
 
 typedef enum {
-
 	FILE_NONE = 0,
 	FILE_WAITING,
 	FILE_CONV_OK
-
 } ETAT_CONV_FILE;
 
 typedef enum {
-
 	FILE_ATTENTE = 0,
 	FILE_SELECTED,
 	FILE_SELECTED_LC
-	
 } ETAT_CONVFILE;
 
 typedef enum {
-
 	VERIF_FILE_NONE = 0,
 	VERIF_FILE_BAD,
 	VERIF_FILE_OK
-
 } VERIF_FILE;
 
 typedef enum {
-
 	ETAT_SCAN_NONE = 0,
 	ETAT_SCAN_DEMANDE,
 	ETAT_SCAN_OK
-
 } ETAT_SCAN;
 
 /*
@@ -317,28 +289,22 @@ RMS/ALBUM
     Ajustement du volume moyen pour un groupe de fichiers en respectant les écarts de niveau moyen entre chacun d'eux
 RMS
     Ajustement du volume moyen de chaque de fichier
-    
-    sed -i 's/ANCIENNE PHRASE/NOUVELLE PHRASE/g' *.c
-    sed -i 's/ANCIENNE PHRASE/NOUVELLE PHRASE/g' *.h
 */
 typedef enum {
 	NORM_NONE = 0,
 	NORM_READY_FOR_SELECT,						// Pret a la selection wav,mp3, ogg
 	NORM_PEAK_ALBUM,						// NORM_PEAK_ALBUM
 	NORM_PEAK,							// NORM_PEAK
-	NORM_RMS_MIX_ALBUM,						// (scan) NORM_RMS_MIX_ALBUM
-	NORM_RMS_FIX							// (scan) NORM_RMS_FIX
-	
+	NORM_RMS_MIX_ALBUM,						//( scan) NORM_RMS_MIX_ALBUM
+	NORM_RMS_FIX							//( scan) NORM_RMS_FIX
 } ETAT_NORMALISE;
 
 typedef enum {
-
 	RPG_NONE = 0,							// Attente de selection
 	RPG_ATTENTE,							// Attente de selection
 	RPG_PISTE,							// Mode PISTE
 	RPG_ALBUM,							// Mode ALBUM
 	RPG_EFFACER							// Mode EFFACER
-	
 } ETAT_REPLAYGAIN;
 
 typedef enum {
@@ -350,7 +316,6 @@ typedef enum {
 	ETAT_SELECT_EXIST,
 	ETAT_SELECT_EXPERT,
 	ETAT_SELECT_EXPERT_EXIST
-	
 } ETAT_SELECTION;
 
 typedef enum {
@@ -358,14 +323,12 @@ typedef enum {
 	FILE_ETAT_PLAY_PRG_ABSENT,
 	FILE_ETAT_PLAY_ATTENTE,
 	FILE_ETAT_PLAY
-	
 } ETAT_PLAY_FILE;
 
 typedef enum {
 	FILE_TRASH_NONE = 0,
 	FILE_TRASH_OK,
 	FILE_TRASH_VERIF_OK
-	
 } ETAT_TRASH_FILE;
 
 enum {
@@ -377,17 +340,13 @@ enum {
 	ETAT_FROM_WAV_TO_AAC,
 	ETAT_FROM_WAV_TO_MPC,
 	ETAT_FROM_WAV_TO_MP3,
-	
 	ETAT_BOOL_TOTAL
 };
 
 
 typedef struct {
-
 	ETAT_PLAY_FILE		 EtatPlay;				// 
-
 	gchar			*name_dest;				// Nom du fichier de destination sans le path ni l'extension
-
 	gchar			*dest_flac;				// 
 	gchar			*dest_wav;				// 
 	gchar			*dest_mp3;				// 
@@ -400,7 +359,6 @@ typedef struct {
 	gchar			*dest_wavpack_md5;			// 
 	gchar			*tmp_flac;				// 
 	gchar			*tmp_wav;				// 
-		
 	gchar			*tmp_sox;				// wav to wav
 	gchar			*tmp_sox_24;				// wav to wav
 	gchar			*tmp_mp3;				// 
@@ -417,9 +375,7 @@ typedef struct {
 	gchar			*tmp_wavpack;				// 
 	gchar			*tmp_wavpack_md5;			// 
 	gchar			*tmp_ac3;				// 
-	
 	gboolean		 BoolEtatConv [ ETAT_BOOL_TOTAL ];	// 
-	
 	ETAT_CONV_FILE		 Etat_Flac;				// 
 	ETAT_CONV_FILE		 Etat_Wav;				// 
 	ETAT_CONV_FILE		 Etat_Mp3;				// 
@@ -429,7 +385,6 @@ typedef struct {
 	ETAT_CONV_FILE		 Etat_Mpc;				// 
 	ETAT_CONV_FILE		 Etat_Ape;				// 
 	ETAT_CONV_FILE		 Etat_wavpack;				// 
-
 	gboolean		 BoolNewString;
 } CONV_FIC;
 
@@ -453,12 +408,9 @@ typedef struct {
 	gchar			*namefile;				// Nom complet du fichier
 	gchar			*NameFileCopyFromNormalizate;		// 
 	gchar			*NameDest;				// Nom de la destination									
-
 	TYPE_FILE_IS		 type_infosong_file_is;			// Type du fichier
 	void 			*info;					// En fonction du type de fichier pointeur sur INFO_xxx
-
 	ETAT_TRASH_FILE		 EtatTrash;				// Etat pour la poubelle
-
 	ETAT_SELECTION		 EtatSelection_Wav;			// Etat de la selection WAV
 	ETAT_SELECTION		 EtatSelection_Flac;			// Etat de la selection FLAC
 	ETAT_SELECTION		 EtatSelection_Ape;			// Etat de la selection APE
@@ -468,7 +420,6 @@ typedef struct {
 	ETAT_SELECTION		 EtatSelection_Aac;			// Etat de la selection AAC
 	ETAT_SELECTION		 EtatSelection_Mpc;			// Etat de la selection MPC
 	ETAT_SELECTION		 EtatSelection_Mp3;			// Etat de la selection MP3
-	
 	ETAT_NORMALISE		 Etat_Normalise;			// Etat de la selection de normalisation
 	ETAT_SCAN		 Etat_Scan;				// Etat de la selection du scan
 	gint			 LevelMix;				// Niveau du MIX
@@ -476,11 +427,8 @@ typedef struct {
 	CONV_FIC		*PConv;					// Pointeur pour conversion de tous les fichiers
 	CONV_FIC_WAV		*PConvWav;				// Pointeur pour conversion WAV TO WAV
 	CONV_FIC_MP3OGG		*PConvMp3Ogg;				// Pointeur pour modification bitrate mp3 et ogg
-	
 	TYPE_REMOVE_STRUCT	 BoolRemove;				// TRUE si suppression de la liste sinon FALSE
-	
 	TYPE_MP3OGG		 TypeMp3Ogg;				// type, debit, mode
-	
 } DETAIL;
 
 extern GList *entetefile;						// pointeur sur DETAIL
@@ -550,7 +498,6 @@ typedef struct {
 	GtkWidget		*Adr_scroll;				// Adresse
 	GtkListStore		*Adr_List_Store;			// Adresse
 	GtkTreeModel		*Adr_Tree_Model;			// Adresse
-	
 	GtkTreeSelection	*Adr_Line_Selected;			// Adresse
 	GtkWidget		*Adr_TreeView;				// Adresse
 	GtkWidget		*Adr_Entry_Dest;			// Adresse
@@ -576,12 +523,10 @@ typedef struct {
 	GtkWidget		*Adr_scroll;				// Adresse
 	GtkListStore		*Adr_List_Store;			// Adresse
 	GtkTreeModel		*Adr_Tree_Model;			// Adresse
-	
 	GtkTreeSelection	*Adr_Line_Selected;			// Adresse
 	GtkWidget		*Adr_TreeView;				// Adresse
 	GtkWidget		*Adr_Entry_Dest;			// Adresse
 	GtkWidget		*Adr_Button_Dest;			// Adresse
-	
 	GtkComboBox		*Adr_combobox_DestFile;			// Adresse
 	GdkPixbuf		*Pixbuf_NotInstall;			// not_install.png
 	GtkCellRenderer		*Renderer;
@@ -597,7 +542,6 @@ typedef struct {
 	GtkComboBox		*Adr_Widget_Oggenc_bitrate;
 	GtkComboBox		*Adr_Widget_Oggenc_managed;
 	GtkComboBox		*Adr_Widget_Oggenc_downmix;
-	
 } VAR_FILE_MP3OGG;
 
 extern VAR_FILE_MP3OGG var_file_mp3ogg;
@@ -621,14 +565,12 @@ typedef struct {
 	GtkTreeViewColumn	*Adr_ColumnFileTagsType;
 	GtkTreeViewColumn	*Adr_ColumnFileTagsTime;
 	GtkTreeViewColumn	*Adr_ColumnFileTagsName;
-	
 } VAR_FILE_TAGS;
 
 extern VAR_FILE_TAGS var_file_tags;
 
 
 typedef enum {
-	
 	// SELECTION ou DESELECTION POUR LES CONVERSIONS
 	FILE_CONV_DESELECT_ALL = 0,
 	FILE_CONV_DESELECT_V,
@@ -637,17 +579,14 @@ typedef enum {
 	FILE_CONV_SELECT_EXPERT_V,
 	FILE_CONV_SELECT_H,
 	FILE_CONV_SELECT_EXPERT_H,
-	
 	// SELECTION ou DESELECTION POUR LE REPLAYGAIN
 	FILE_REPLAYGAIN_DESELECT_V,
 	FILE_REPLAYGAIN_SELECT_PISTE,
 	FILE_REPLAYGAIN_SELECT_ALBUM,
 	FILE_REPLAYGAIN_SELECT_NETTOYER,
-	
 	// SELECTION ou DESELECTION POUR TRASH
 	FILE_TRASH_DESELECT_V,
 	FILE_TRASH_SELECT_V,
-	
 	// SELECTION ou DESELECTION POUR TRASH
 	FILEWAV_FREQUENCY_CELL_HERTZ,
 	FILEWAV_FREQUENCY_COL_HERTZ,
@@ -655,32 +594,31 @@ typedef enum {
 	FILEWAV_TRACK_COL,
 	FILEWAV_QUANTIFICATION_CELL,
 	FILEWAV_QUANTIFICATION_COL
-	
 } TYPE_SET_FROM_POPUP_FILE;
 
-gchar		*file_get_time (DETAIL *detail);
-void		file_scrolledwindow_file_realize (GtkWidget *widget);
-void		file_set_flag_buttons (void);
-void		file_button_del_file_clicked (void);
-void		file_pixbuf_update_glist (void);
-void		file_affiche_glist (void);
-gboolean	file_get_bool_ReplaygainApply (void);
-gboolean	file_get_bool_ReplaygainClear_file (void);
-gboolean	file_get_bool_normalize_file (void);
-gboolean	file_get_bool_is_conversion (void);
-gint		file_get_scan (void);
-void		file_verify_before_conversion (void);
-gchar		*file_get_pathname_dest (DETAIL *detail, gchar *NewExt);
-gchar		*file_get_size (DETAIL *detail);
-void		on_file_button_del_file_clicked (GtkButton *button, gpointer user_data);
-void		file_from_popup (TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, TYPE_FILE_IS TypeFileIs);
+gchar		*file_get_time( DETAIL *detail );
+void		file_scrolledwindow_file_realize( GtkWidget *widget );
+void		file_set_flag_buttons( void );
+void		file_button_del_file_clicked( void );
+void		file_pixbuf_update_glist( void );
+void		file_affiche_glist( void );
+gboolean	file_get_bool_ReplaygainApply( void );
+gboolean	file_get_bool_ReplaygainClear_file( void );
+gboolean	file_get_bool_normalize_file( void );
+gboolean	file_get_bool_is_conversion( void );
+gint		file_get_scan( void );
+void		file_verify_before_conversion( void );
+gchar		*file_get_pathname_dest( DETAIL *detail, gchar *NewExt );
+gchar		*file_get_size( DETAIL *detail );
+void		on_file_button_del_file_clicked( GtkButton *button, gpointer user_data );
+void		file_from_popup( TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, TYPE_FILE_IS TypeFileIs );
 
 /*
 *---------------------------------------------------------------------------
 * FILE_SCAN_DB.C
 *---------------------------------------------------------------------------
 */
-void		FileScanDB_action (gboolean BoolAllScan);
+void		FileScanDB_action( gboolean BoolAllScan );
 
 /*
 *---------------------------------------------------------------------------
@@ -689,9 +627,9 @@ void		FileScanDB_action (gboolean BoolAllScan);
 */
 #include "fileselect.h"
 
-void		fileanalyze_remove_entetefile (void);
-void		fileanalyze_add_file_to_treeview (TYPE_FILESELECTION p_TypeFileselection, GSList *p_list);
-gboolean	fileanalyze_exist (DETAIL *detail, gchar *NewExt);
+void		fileanalyze_remove_entetefile( void );
+void		fileanalyze_add_file_to_treeview( TYPE_FILESELECTION p_TypeFileselection, GSList *p_list );
+gboolean	fileanalyze_exist( DETAIL *detail, gchar *NewExt );
 
 
 /*
@@ -699,17 +637,17 @@ gboolean	fileanalyze_exist (DETAIL *detail, gchar *NewExt);
 * FILE_CONV.C
 *---------------------------------------------------------------------------
 */
-void		fileconv_action (void);
+void		fileconv_action( void );
 
 /*
 *---------------------------------------------------------------------------
 * FILE_MP3OGG.C
 *---------------------------------------------------------------------------
 */
-void		FileMp3Ogg_set_flag_buttons (void);
-void		FileMp3Ogg_affiche_glist (void);
-gboolean	FileMp3Ogg_del_file_clicked (void);
-void		FileMp3Ogg_change_parameters (void);
+void		FileMp3Ogg_set_flag_buttons( void );
+void		FileMp3Ogg_affiche_glist( void );
+gboolean	FileMp3Ogg_del_file_clicked( void );
+void		FileMp3Ogg_change_parameters( void );
 
 
 /*
@@ -717,7 +655,7 @@ void		FileMp3Ogg_change_parameters (void);
 * FILE_MP3OGG_CONV.C
 *---------------------------------------------------------------------------
 */
-void		filemp3oggconv_apply_regul_mp3ogg_by_conv (void);
+void		filemp3oggconv_apply_regul_mp3ogg_by_conv( void );
 
 
 /*
@@ -725,28 +663,28 @@ void		filemp3oggconv_apply_regul_mp3ogg_by_conv (void);
 * FILE_WAV.C
 *---------------------------------------------------------------------------
 */
-void		FileWav_affiche_glist (void);
-void		FileWav_change_parameters (void);
-void		FileWav_set_flag_buttons (void);
-void		FileWav_from_popup (TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, gint freq, gint voie, gint bits);
+void		FileWav_affiche_glist( void );
+void		FileWav_change_parameters( void );
+void		FileWav_set_flag_buttons( void );
+void		FileWav_from_popup( TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, gint freq, gint voie, gint bits );
 
 /*
 *---------------------------------------------------------------------------
 * FILE_TAGS.C
 *---------------------------------------------------------------------------
 */
-void		FileTags_affiche_glist (void);
-gboolean	FileWav_del_file_clicked (void);
-gboolean	FileTags_del_file_clicked (void);
-void		FileTags_appliquer_clicked (void);
-void		FileTags_set_flag_buttons (void);
+void		FileTags_affiche_glist( void );
+gboolean	FileWav_del_file_clicked( void );
+gboolean	FileTags_del_file_clicked( void );
+void		FileTags_appliquer_clicked( void );
+void		FileTags_set_flag_buttons( void );
 
 /*
 *---------------------------------------------------------------------------
 * FILE_WAV_CONV.C
 *---------------------------------------------------------------------------
 */
-void		filewavconv_apply (void);
+void		filewavconv_apply( void );
 
 /*
 *---------------------------------------------------------------------------
@@ -754,17 +692,15 @@ void		filewavconv_apply (void);
 *---------------------------------------------------------------------------
 */
 typedef enum {
-	
 	TYPE_REPLAYGAINCLEAR = 0,
 	TYPE_NORMALISE,
 	TYPE_CONVERSION,
 	TYPE_REPLAYGAINAPPLY,
 	TYPE_TRASH
-
 } FILEACTION_TYPE;
 
-void		fileaction_choice (void);
-void		fileaction_set_end (FILEACTION_TYPE FileActionType);
+void		fileaction_choice( void );
+void		fileaction_set_end( FILEACTION_TYPE FileActionType );
 
 /*
 *---------------------------------------------------------------------------
@@ -785,12 +721,12 @@ typedef struct {
 	gchar		*PtrStrBitrate;
 } PARAM_FILELC;
 
-gint		filelc_get_command_line_remove (void);
-gint		filelc_get_command_line_nice (void);
-void		filelc_get_command_line (PARAM_FILELC *param_filelc);
-void		filelc_get_command_line_extract (PARAM_FILELC *param_filelc);
-GList		*filelc_remove_glist (GList *New);
-void		filelc_get_command_line_extract_elem (gint Elem, gchar *Dev, gchar *Dest);
+gint		filelc_get_command_line_remove( void );
+gint		filelc_get_command_line_nice( void );
+void		filelc_get_command_line( PARAM_FILELC *param_filelc );
+void		filelc_get_command_line_extract( PARAM_FILELC *param_filelc );
+GList		*filelc_remove_glist( GList *New );
+void		filelc_get_command_line_extract_elem( gint Elem, gchar *Dev, gchar *Dest );
 
 
 /*
@@ -798,11 +734,11 @@ void		filelc_get_command_line_extract_elem (gint Elem, gchar *Dev, gchar *Dest);
 * FILE_TRASH.C
 *---------------------------------------------------------------------------
 */
-void       filetrash_action (void);
-gboolean   filetrash_ok (void);
-gboolean   filetrash_move_to_trash (gchar *Name);
-gchar     *filetrash_get_trash (void);
-void       filetrash_test_trash_is_ok (void);
+void		filetrash_action( void );
+gboolean	filetrash_ok( void );
+gboolean	filetrash_move_to_trash( gchar *Name );
+gchar		*filetrash_get_trash( void );
+void		filetrash_test_trash_is_ok( void );
 
 
 #endif
