@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -103,7 +103,9 @@ static void filemp3oggconv_thread (void *arg)
 
 				INFO_MP3 *InfoMp3 = (INFO_MP3 *)detail->info;
 
-				/* mpg321 SOURCE MP3 -> DESTINATION WAV
+				/* MPLAYER_MP3_TO_WAV
+				*  MPLAYER_WAV_TO_WAV
+				*  SOURCE MP3 -> DESTINATION WAV
 				*  ------------------------------------
 				*/
 				g_print ("SOURCE MP3<%s>\n", detail->namefile);
@@ -284,7 +286,11 @@ static gint filemp3oggconv_timeout (gpointer data)
 		WindScan_close ();
 		FileMp3Ogg_set_flag_buttons ();
 
-		NotifySend_msg (_("XCFA: Modification bitrate"), _("Ok"));
+		if (FALSE == conv.bool_stop) {
+			NotifySend_msg (_("XCFA: Modification bitrate"), _("Ok"), conv.bool_stop);
+		} else {
+			NotifySend_msg (_("XCFA: Modification bitrate"), _("Arret par l'utilisateur"), conv.bool_stop);
+		}
 	}
 
 	return (TRUE);
@@ -332,11 +338,6 @@ void filemp3oggconv_set_flags_before_conversion (void)
 					} else {
 						PConvMp3Ogg->destfile = file_get_pathname_dest (detail, "mp3");
 					}
-					// g_print("PConvMp3Ogg->destwav  = %s\n", PConvMp3Ogg->destwav);
-					// g_print("PConvMp3Ogg->destsox  = %s\n", PConvMp3Ogg->destsox);
-					// g_print("PConvMp3Ogg->destmp3  = %s\n", PConvMp3Ogg->destmp3);
-					// g_print("PConvMp3Ogg->destogg  = %s\n", PConvMp3Ogg->destogg);
-					// g_print("PConvMp3Ogg->destfile = %s\n", PConvMp3Ogg->destfile);
 				}
 			}
 		}
