@@ -32,7 +32,7 @@
 // FILE_IS_MPC
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -177,14 +177,9 @@ TAGS *FileTags_get_tag (DETAIL *detail)
 	}
 	switch (detail->type_infosong_file_is) {
 	case FILE_IS_NONE :
-	case FILE_IS_CUE :
 	case FILE_IS_WAVPACK_MD5 :
 	case FILE_TO_NORMALISE :
 	case FILE_TO_NORMALISE_COLLECTIF :
-	case FILE_IS_IMG :
-	case FILE_IS_HTML :
-	case FILE_IS_TXT :
-	case FILE_IS_XCFA_GEN_CONF :
 	case FILE_TO_REPLAYGAIN :
 		break;
 		
@@ -974,11 +969,11 @@ void FileTags_changed_selection_row (GtkTreeSelection *selection, gpointer data)
 // 
 gboolean FileTags_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-	if (keys.BoolGDK_Control_A == TRUE) {
+	if( TRUE == keys.BoolGDK_Control_A ) {	// CONTROL_A
 		gtk_tree_selection_unselect_all (var_file_tags.Adr_Line_Selected);
 		gtk_tree_selection_select_all (var_file_tags.Adr_Line_Selected);
 	}
-	if (event->keyval == GDK_Delete) {
+	if (keys.keyval == GDK_Delete) {
 		GtkTreeIter   iter;
 		if (gtk_tree_model_get_iter_first (var_file_tags.Adr_Tree_Model, &iter)) {
 			on_file_button_del_file_clicked (NULL, NULL);
