@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -712,11 +712,11 @@ static void FileWav_drag_data_drop (GtkWidget *widget,
 // 
 gboolean FileWav_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-	if (keys.BoolGDK_Control_A == TRUE) {
+	if( TRUE == keys.BoolGDK_Control_A ) {	// CONTROL_A
 		gtk_tree_selection_unselect_all (var_file_wav.Adr_Line_Selected);
 		gtk_tree_selection_select_all (var_file_wav.Adr_Line_Selected);
 	}
-	if (event->keyval == GDK_Delete) {
+	if (keys.keyval == GDK_Delete) {
 		GtkTreeIter   iter;
 		if (gtk_tree_model_get_iter_first (var_file_wav.Adr_Tree_Model, &iter)) {
 			on_file_button_del_file_clicked (NULL, NULL);
