@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -322,7 +322,11 @@ static gint filewavconv_timeout (gpointer data)
 			conv.TmpRep  = libutils_remove_temporary_rep (conv.TmpRep);
 		}
 		
-		NotifySend_msg (_("XCFA: Conversions WAV TO WAV"), _("Ok"));
+		if (FALSE == conv.bool_stop) {
+			NotifySend_msg (_("XCFA: Conversions WAV TO WAV"), _("Ok"), conv.bool_stop);
+		} else {
+			NotifySend_msg (_("XCFA: Conversions WAV TO WAV"), _("Arret par l'utilisateur"), conv.bool_stop);
+		}
 	}
 	
 	return (TRUE);
