@@ -26,12 +26,18 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
 	#include <libintl.h>
 	#define _(String) gettext (String)
+	// #include <libintl.h>
+	//#define _(String) gettext (String)
+	/* INTERNATIONALISATION DE DATAS DEPUIS LES STRUCTURES :
+	 *	http://chl.be/glmf/www.linuxmag-france.org/old/lm5/inter.html
+	 */
+	#define gettext_noop(x) (x) 
 #endif
 
 #include <gtk/gtk.h>
@@ -80,12 +86,11 @@ typedef struct {
 
 typedef struct {
 
-	gboolean		 BoolInitDatas;
 	TYPE_FILESELECTION	 TypeFileSelection;
 	
 } VAR_FILESELECT;
 
-VAR_FILESELECT	VarFileSelect = { FALSE };
+VAR_FILESELECT	VarFileSelect;
 
 
 /*
@@ -108,17 +113,17 @@ void ON_button_PATH_POCHETTE_clicked (GtkButton *button, gpointer user_data);
 
 SELECT Select [ ] =
 {
-
-{NULL,	_REP_SIMPLE_,		NULL, ON_button_PATH_CHOICE_DESTINATION_clicked,		NULL},
-{NULL,	_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{NULL,	_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{NULL,	_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{NULL,	_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{NULL,	_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{NULL,	_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{NULL,	_FILE_IMG_MULTIPLE_,	NULL, ON_button_PATH_IMPORT_IMAGES_clicked,			NULL},
-{NULL,	_FILE_MULTIPLE_,	NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
-{NULL,	_FILE_MULTIPLE_,	NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
+{gettext_noop("Choix d'un dossier de destination"),			_REP_SIMPLE_,		NULL, ON_button_PATH_CHOICE_DESTINATION_clicked,		NULL},
+{gettext_noop("Choix d'un fichier CUE WAV FLAC OGG MP3 APE WMA"),	_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choix d'un fichier musical"),				_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choix d'un fichier"),					_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choix de fichiers"),					_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choix de fichiers WAV"),					_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choix de fichiers MP3/OGG"),				_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choix de fichiers FLAC MPC OGG MP3"),			_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Importer des images pour la pochette"),			_FILE_IMG_MULTIPLE_,	NULL, ON_button_PATH_IMPORT_IMAGES_clicked,			NULL},
+{gettext_noop("Choix d'un chemin de stockage des images"),		_FILE_MULTIPLE_,	NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
+{gettext_noop("Choix d'un lieu de sauvegarde"),				_FILE_MULTIPLE_,	NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
  
 {NULL, -1}
 };
@@ -174,8 +179,15 @@ void ON_button_PATH_LOAD_ONE_FILE_clicked (GtkButton *button, gpointer user_data
 	gchar	*Path = NULL;
 	GSList	*List = NULL;
 	
-	if (_PATH_LOAD_ONE_FILE_ == VarFileSelect.TypeFileSelection || _PATH_LOAD_SPLIT_FILE_ == VarFileSelect.TypeFileSelection) {
-		// Path = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (Select[ Choice ].AdrFileChooser));
+	if( _PATH_LOAD_FILE_MUSIC_ == VarFileSelect.TypeFileSelection ) {
+		Path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (Select[ Choice ].AdrFileChooser));
+		if (Select[ Choice ].Func_Extern) (*Select[ Choice ].Func_Extern) (Path);
+		g_free (Path);
+		Path = NULL;
+		gtk_widget_destroy(Select[ Choice ].AdrFileChooser);
+		Select[ Choice ].AdrFileChooser = NULL;
+	}
+	else if (_PATH_LOAD_ONE_FILE_ == VarFileSelect.TypeFileSelection || _PATH_LOAD_SPLIT_FILE_ == VarFileSelect.TypeFileSelection) {
 		Path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (Select[ Choice ].AdrFileChooser));
 		gtk_widget_destroy(Select[ Choice ].AdrFileChooser);
 		Select[ Choice ].AdrFileChooser = NULL;
@@ -316,64 +328,22 @@ void fileselect_on_button_ok_clicked (GtkButton *button, gpointer user_data)
 // 
 void chooserDialog_preview_update (GtkFileChooser *filechooser, gpointer data)
 {
-	/*-- WIDGETS --*/
 	GtkWidget	*preview = NULL;
 	GdkPixbuf	*pixbuf = NULL;
 	gchar		*filename = NULL;
-	gboolean	have_preview;
 
 	preview = GTK_WIDGET (data);
-	filename = gtk_file_chooser_get_preview_filename(filechooser);
-
-	/*
-	Lors de l'ouverture d'un repertoire, filename vaut toujours NULL,
-	(du moins sous windows).
-	Si le test n'est pas fait,
-	la seule concequence est un WARNING en console.
-	*/
-	if (filename != NULL) {
-		/*Creation du pixbud de l'image*/
-		pixbuf = gdk_pixbuf_new_from_file_at_size(filename, 150, 150, NULL);
-		/*Definition de l'etat d'affichage de previsualisation*/
-		have_preview = (pixbuf != NULL);
-
+	if( NULL != (filename = gtk_file_chooser_get_preview_filename(filechooser))) {
+		pixbuf = gdk_pixbuf_new_from_file_at_size(filename, 200, 200, NULL); 
 		g_free (filename);
 		filename = NULL;
-
-		/*Creation de l'image*/
-		gtk_image_set_from_pixbuf (GTK_IMAGE(preview), pixbuf);
-		/*if (pixbuf) gdk_pixbuf_unref (pixbuf);*/
-		if (pixbuf) g_object_unref(pixbuf);
-		
-		gtk_file_chooser_set_preview_widget_active(filechooser, have_preview);
+		if( NULL != pixbuf ) {
+			gtk_image_set_from_pixbuf (GTK_IMAGE(preview), pixbuf);
+			g_object_unref(pixbuf);
+			gtk_file_chooser_set_preview_widget_active(filechooser, TRUE);
+		}
 	}
 }
-// 
-// 
-void fileselect_remove_comment (void)
-{
-	gint index;
-		
-	for (index = 0; index < _NB_PATH_; index ++) {
-		g_free (Select[ index ].Title);
-		Select[ index ].Title = NULL;
-	}
-}
-// 
-// 
-void fileselect_init_comment (void)
-{
-	Select[ _PATH_CHOICE_DESTINATION_ ].Title	= g_strdup (_("Choix d'un dossier de destination"));
-	Select[ _PATH_LOAD_SPLIT_FILE_ ].Title		= g_strdup (_("Choix d'un fichier CUE WAV FLAC OGG MP3 APE WMA"));
-	Select[ _PATH_LOAD_ONE_FILE_ ].Title		= g_strdup (_("Choix d'un fichier"));
-	Select[ _PATH_LOAD_FILE_ALL_ ].Title		= g_strdup (_("Choix de fichiers"));
-	Select[ _PATH_LOAD_FILE_WAV_ ].Title		= g_strdup (_("Choix de fichiers WAV"));
-	Select[ _PATH_LOAD_FILE_MP3OGG_ ].Title		= g_strdup (_("Choix de fichiers MP3/OGG"));
-	Select[ _PATH_LOAD_FILE_TAGS_ ].Title		= g_strdup (_("Choix de fichiers FLAC MPC OGG MP3"));
-	Select[ _PATH_IMPORT_IMAGES_ ].Title		= g_strdup (_("Importer des images pour la pochette"));
-	Select[ _PATH_STOCKE_IMAGES_POCHETTE_ ].Title	= g_strdup (_("Choix d'un chemin de stockage des images"));
-	Select[ _PATH_DEST_FILE_POSTSCRIPT_ ].Title	= g_strdup (_("Choix d'un lieu de sauvegarde"));
-}
 // Demande de creation de la fenetre de selection de fichier(s) ou de repertoire
 // 
 void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Extern)
@@ -385,11 +355,6 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 	GtkWidget *button_ok;
 	GtkWidget *preview;
 	GtkFileFilter *filter;
-
-	if (VarFileSelect.BoolInitDatas == FALSE) {
-		fileselect_init_comment ();
-		VarFileSelect.BoolInitDatas = TRUE;
-	}
 	
 	if (_NB_PATH_ <= 0) return;
 	if (Choice < 0 || Choice > _NB_PATH_) return;
@@ -505,7 +470,7 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 		
 		}
-		else if (Choice == _PATH_LOAD_FILE_ALL_) {
+		else if( Choice == _PATH_LOAD_FILE_ALL_ || Choice == _PATH_LOAD_FILE_MUSIC_ ) {
 			filter = gtk_file_filter_new ();
 			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
 			gtk_file_filter_add_pattern (filter, "*.wav");
@@ -621,6 +586,37 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_add_pattern (filter, "*.AC3");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 		}
+		else if (Choice == _PATH_LOAD_FILE_WAV_) {
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
+			gtk_file_filter_add_pattern (filter, "*.wav");
+			gtk_file_filter_add_pattern (filter, "*.WAV");
+			gtk_file_filter_set_name (filter, "*.wav");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+		}
+		else if (Choice == _PATH_LOAD_FILE_MP3OGG_) {
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
+			gtk_file_filter_add_pattern (filter, "*.ogg");
+			gtk_file_filter_add_pattern (filter, "*.OGG");
+			gtk_file_filter_add_pattern (filter, "*.oga");
+			gtk_file_filter_add_pattern (filter, "*.OGA");
+			gtk_file_filter_add_pattern (filter, "*.mp3");
+			gtk_file_filter_add_pattern (filter, "*.MP3");
+			gtk_file_filter_set_name (filter, "*.mp3 *.ogg");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "OGG (*.ogg)");
+			gtk_file_filter_add_pattern (filter, "*.ogg");
+			gtk_file_filter_add_pattern (filter, "*.OGG");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+			filter = gtk_file_filter_new ();
+			gtk_file_filter_set_name (filter, "MP3 (*.mp3)");
+			gtk_file_filter_add_pattern (filter, "*.mp3");
+			gtk_file_filter_add_pattern (filter, "*.MP3");
+			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
+		}
 		else if (Choice == _PATH_LOAD_FILE_TAGS_) {
 			filter = gtk_file_filter_new ();
 			gtk_file_filter_set_name (filter, _("All Files (*.*)"));
@@ -634,6 +630,7 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 			gtk_file_filter_add_pattern (filter, "*.MPC");
 			gtk_file_filter_add_pattern (filter, "*.mp3");
 			gtk_file_filter_add_pattern (filter, "*.MP3");
+			gtk_file_filter_set_name (filter, "*.flac *.mpc *.mp3 *.ogg");
 			gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filechooserdialog), filter);
 			
 			filter = gtk_file_filter_new ();
