@@ -33,6 +33,7 @@ typedef enum {
 
 	_PATH_CHOICE_DESTINATION_ = 0,
 	_PATH_LOAD_SPLIT_FILE_,
+	_PATH_LOAD_FILE_MUSIC_,
 	_PATH_LOAD_ONE_FILE_,
 	_PATH_LOAD_FILE_ALL_,
 	_PATH_LOAD_FILE_WAV_,
@@ -47,7 +48,6 @@ typedef enum {
 } TYPE_FILESELECTION;
 
 
-void     fileselect_remove_comment (void);
 void	 fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Extern);
 void	 fileselect_clear_glist (void);
 GList	*fileselect_set_glist_from_str (gchar *p_str);
