@@ -27,7 +27,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -1051,118 +1051,109 @@ SHNTAG *GetInfo_shntool (gchar *file)
 	return ((SHNTAG *)ShnTag);
 }
 // 
+// RECONNAISSANCE ENTETE FICHIER:
+// 	FILE_IS_M4A
+// 	FILE_IS_WAVPACK
+// 	FILE_IS_WAVPACK_MD5
+// 	FILE_IS_WAV
+// 	FILE_IS_SHN
+// 	FILE_IS_RM
+// 	FILE_IS_OGG
+// 	FILE_IS_MPC
+// 	FILE_IS_AC3
+// 	FILE_IS_MP3
+// 	FILE_IS_FLAC
+// 	FILE_IS_APE
+// 	FILE_IS_AIFF
+// 	FILE_IS_DTS
+// SI COMMANDE file IS OK TEST DE:
+// 	FILE_IS_AAC
+// 	FILE_IS_WMA
 // 
-TYPE_FILE_IS GetInfo_file_is (gchar *PathName)
+TYPE_FILE_IS GetInfo_file_is( gchar *PathName )
 {
 	GString		*gstr = NULL;
 	TYPE_FILE_IS	TypeFileRet = FILE_IS_NONE;
 	
+	
 	gstr = GetInfo_file (PathName);
-	if (*gstr->str) {
-		if (FileIs_aiff (PathName)) {
-			TypeFileRet = FILE_IS_AIFF;
-		}
-		else if (FileIs_shn (PathName)) {
-			TypeFileRet = FILE_IS_SHN;
-		}
-		else if (FileIs_mpc (PathName)) {
-			TypeFileRet = FILE_IS_MPC;
-		}
-		else if (strstr (gstr->str, "AAC")) {
+	// g_print( "gstr =\n%s\n", gstr->str );
+	// ABANDON SI LA COMMANDE file NE TROUVE PAS LE TYPE DE FICHIER
+	if( 0 == strcmp( gstr->str, "data" )) {
+		TypeFileRet = FILE_IS_NONE;
+		PRINT("ERROR: LA COMMANDE file NE TROUVE RIEN :/");
+	}
+	// UNE PETITE CHANCE SE PRESENTE ICI POUR AAC
+	else {
+		// FILE_IS_AAC
+		if( strstr (gstr->str, "AAC" ) || strstr (gstr->str, "MPEG ADTS, AAC," )) {
 			TypeFileRet = FILE_IS_AAC;
 		}
-		else if (FileIs_ac3 (PathName)) {
-			TypeFileRet = FILE_IS_AC3;
-		}
-		else if (FileIs_ape (PathName)) {
-			TypeFileRet = FILE_IS_APE;
-		}
-		else if (FileIs_dts (PathName)) {
-			TypeFileRet = FILE_IS_DTS;
-		}
-		else if (strstr (gstr->str, "WAVE audio")) {
-			TypeFileRet = FILE_IS_WAV;
-		}
-	
-		/*	XWD X Window Dump image data
-		 *	
-		 *	http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=511764
-		 */
-		else if (strstr (gstr->str, "MP3 file") ||
-			 strstr (gstr->str, "MP3 encoding") ||
-			 strstr (gstr->str, "MPEG ADTS, layer III") ||
-			 strstr (gstr->str, "XWD X Window Dump image data")) {
-			 TypeFileRet = FILE_IS_MP3;
-			// PRINT("IS MP3");
-		}
-		else if (strstr (gstr->str, "Ogg data") && strstr (gstr->str, "Vorbis audio")) {
-			TypeFileRet = FILE_IS_OGG;
-		}
-		else if (strstr (gstr->str, "ISO Media, MPEG v4 system")) {
-			TypeFileRet = FILE_IS_M4A;
-		}
+		// FILE_IS_WMA
 		else if (strstr (gstr->str, "Microsoft ASF")) {
 			TypeFileRet = FILE_IS_WMA;
 		}
-		else if (FileIs_wavpack (PathName)) {
-			TypeFileRet =  FILE_IS_WAVPACK;
-		}
-		else if (strstr (gstr->str, "RealMedia file")) {
-			TypeFileRet = FILE_IS_RM;
-		}
-		else if (strstr (gstr->str, "FLAC audio bitstream data")) {
-			TypeFileRet = FILE_IS_FLAC;
-		}
-		else if (strstr (gstr->str, "image data") || strstr (gstr->str, "PNG image")) {
-			TypeFileRet = FILE_IS_IMG;
-		}
-		else if (strstr (gstr->str, "HTML document text")) {
-			TypeFileRet = FILE_IS_HTML;
-		}
-		else if (strstr (gstr->str, "ASCII") && strstr (gstr->str, "text")) {
-			TypeFileRet = FILE_IS_TXT;
-		}
-		else {
-			TypeFileRet = FILE_IS_NONE;
-		}
+	
 	}
 	g_string_free (gstr, TRUE);
 	gstr = NULL;
+	if( FILE_IS_AAC == TypeFileRet || FILE_IS_WMA == TypeFileRet ) return( TypeFileRet );
 	
-	if (FILE_IS_NONE == TypeFileRet) {
-		if (FileIs_ac3 (PathName)) {
-			TypeFileRet = FILE_IS_AC3;
-		}
-		else if (FileIs_ape (PathName)) {
-			TypeFileRet = FILE_IS_APE;
-		}
-		else if (FileIs_mp3 (PathName)) {
-			TypeFileRet = FILE_IS_MP3;
-		}
-		else if (FileIs_aiff (PathName)) {
-			TypeFileRet = FILE_IS_AIFF;
-		}
-		else if (FileIs_flac (PathName)) {
-			TypeFileRet = FILE_IS_FLAC;
-		}
-		else if (FileIs_ape (PathName)) {
-			TypeFileRet = FILE_IS_APE;
-		}
-		else if (FileIs_mpc (PathName)) {
-			TypeFileRet = FILE_IS_MPC;
-		}
-		else if (FileIs_wav (PathName)) {
-			TypeFileRet = FILE_IS_WAV;
-		}
-		else if (FileIs_flac (PathName)) {
-			TypeFileRet = FILE_IS_FLAC;
-		}
-		else if (FileIs_shn (PathName)) {
-			TypeFileRet = FILE_IS_SHN;
-		}
+	// FILE_IS_M4A
+	if( TRUE == FileIs_m4a( PathName )) {
+		TypeFileRet = FILE_IS_M4A;
+	}
+	// FILE_IS_WAVPACK
+	// FILE_IS_WAVPACK_MD5
+	else if( TRUE == FileIs_wavpack( PathName )) {
+		TypeFileRet = FILE_IS_WAVPACK;
+	}
+	// FILE_IS_WAV
+	else if( TRUE == FileIs_wav( PathName )) {
+		TypeFileRet = FILE_IS_WAV;
+	}
+	// FILE_IS_SHN
+	else if( TRUE == FileIs_shn( PathName )) {
+		TypeFileRet = FILE_IS_SHN;
+	}
+	// FILE_IS_RM
+	else if( TRUE == FileIs_rm( PathName )) {
+		TypeFileRet = FILE_IS_RM;
+	}
+	// FILE_IS_OGG
+	else if( TRUE == FileIs_ogg( PathName )) {
+		TypeFileRet = FILE_IS_OGG;
+	}
+	// FILE_IS_MPC
+	else if( TRUE == FileIs_mpc( PathName )) {
+		TypeFileRet = FILE_IS_MPC;
+	}
+	// FILE_IS_AC3
+	else if( TRUE == FileIs_ac3( PathName )) {
+		TypeFileRet = FILE_IS_AC3;
+	}
+	// FILE_IS_FLAC
+	else if( TRUE == FileIs_flac( PathName )) {
+		TypeFileRet = FILE_IS_FLAC;
+	}
+	// FILE_IS_APE
+	else if( TRUE == FileIs_ape( PathName )) {
+		TypeFileRet = FILE_IS_APE;
+	}
+	// FILE_IS_DTS
+	else if( TRUE == FileIs_dts( PathName )) {
+		TypeFileRet = FILE_IS_DTS;
+	}
+	// FILE_IS_AIFF
+	else if( TRUE == FileIs_aiff( PathName )) {
+		TypeFileRet = FILE_IS_AIFF;
+	}
+	// FILE_IS_MP3
+	else if( TRUE == FileIs_mp3( PathName )) {
+		TypeFileRet = FILE_IS_MP3;
 	}
 	
-	return (TypeFileRet);
+	return( TypeFileRet );
 }
 
 
