@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -35,6 +35,7 @@
 #endif
 
 #include <gtk/gtk.h>
+// /usr/include/gtk-2.0/gdk/gdkkeysyms.h
 #include <gdk/gdkkeysyms.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -53,7 +54,6 @@
 #include "file.h"
 #include "notify_send.h"
 #include "parse.h"
-#include "prg_init.h"
 #include "scan.h"
 #include "cd_audio.h"
 #include "dvd.h"
@@ -71,7 +71,6 @@
 #include "statusbar.h"
 #include "global.h"
 
-
 // FIXME
 // TODO
 
@@ -81,23 +80,10 @@ HOST_CONF	 HostConf;
 GtkWidget	*AdrLabelStatusbarGlobal = NULL;
 
 KEYS keys = {
-	GDK_NOTHING,	/* eventkey		*/
-	0,		/* type			*/
-	0,		/* state		*/
-	0,		/* keyval		*/
-	0,		/* hardware_keycode	*/
-	"",		/* str			*/
-	FALSE,		/* BoolGDK_KP_Add	*/
-	FALSE,		/* BoolGDK_KP_Subtract	*/
-	FALSE,		/* BoolGDK_plus		*/
-	FALSE,		/* BoolGDK_minus	*/
-	FALSE,		/* BoolGDK_Control_L	*/
-	FALSE,		/* BoolGDK_Control_R	*/
-	FALSE,		/* BoolGDK_Shift_L	*/
-	FALSE,		/* BoolGDK_Shift_R	*/
-	FALSE,		/* BoolGDK_Left		*/
-	FALSE,		/* BoolGDK_Right	*/
-	FALSE		/* BoolGDK_Control_A	*/
+	FALSE,		// gboolean	BoolGDKPress
+	FALSE,		// gboolean	BoolGDK_Control_L_R
+	FALSE,		// gboolean	BoolGDK_Control_A
+	0,		// guint	keyval
 };
 
 
@@ -154,16 +140,16 @@ void remove_memory_apply (void)
 	g_print ("NotifySend_remove ()\n");
 	NotifySend_remove ();
 	
-	g_print ("prginit_remove_comment ()\n");
-	prginit_remove_comment ();
-	
 	g_print ("Parse_remove (PARSE_TYPE_STOCKAGE_CD)\n");
 	Parse_remove (PARSE_TYPE_STOCKAGE_CD);
 	g_print ("Parse_remove (PARSE_TYPE_TITLE_CD)\n");
 	Parse_remove (PARSE_TYPE_TITLE_CD);
 	
-	g_print ("pocheevnt_remove ()\n");
-	pocheevnt_remove ();
+	g_print ("poche_remove_view()\n");
+	poche_remove_view();
+	
+	g_print ("poche_remove_ListImage()\n");
+	poche_remove_ListImage();
 
 	g_print ("libcombo_remove ()\n");
 	libcombo_remove ();
@@ -194,13 +180,23 @@ void remove_memory_apply (void)
 	g_print ("StatusBar_remove ()\n");
 	StatusBar_remove();
 
+	Config.PathPochette = libutils_remove_temporary_rep( Config.PathPochette );
+	
+	if( NULL != Config.PathLoadImg ) {
+		g_free( Config.PathLoadImg );
+		Config.PathLoadImg = NULL;
+	}
+	if( Config.PathSaveImg ) {
+		g_free( Config.PathSaveImg );
+		Config.PathSaveImg = NULL;
+	}
+
 	g_print ("\n");
 }
 // 
 // 
 void on_notebook_general_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
 {
-
 	if (TRUE == Config.BoolConfigOk) {
 		Config.NotebookGeneral = page_num;
 		
@@ -267,148 +263,53 @@ void on_notebook_app_externes_switch_page (GtkNotebook *notebook, GtkNotebookPag
 }
 // 
 // 
-gboolean on_wind_main_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+gboolean on_wind_main_key_press_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )
 {
-	// PRINT_FUNC_LF();
-	if (event->type == GDK_LEAVE_NOTIFY) {
-		// utils_puts_statusbar_global ("");
-	}
-	else if (event->type == GDK_CONFIGURE) {
-		// Apply_New_Size_Tree_View_Audio (wind_main->allocation.width);
-		// Apply_New_Size_Tree_View_File (wind_main->allocation.width);
-	}
-	else if (event->type == GDK_KEY_PRESS) {
-		keys.eventkey           = GDK_KEY_PRESS;
-		keys.type               = event->type;
-		keys.state              = event->key.state;
-		keys.keyval             = event->key.keyval;
-		keys.hardware_keycode   = event->key.hardware_keycode;
-
-		if (event->key.keyval == GDK_Control_L) {
-			keys.BoolGDK_Control_L = TRUE;
-		}
-		else if (event->key.keyval == GDK_Control_R) {
-			keys.BoolGDK_Control_R = TRUE;
-		}
-		else if (event->key.keyval == GDK_Shift_L) {
-			keys.BoolGDK_Shift_L = TRUE;
-		}
-		else if (event->key.keyval == GDK_Shift_R) {
-			keys.BoolGDK_Shift_R = TRUE;
-		}
-		else if (event->key.keyval == GDK_Left) {
-			keys.BoolGDK_Left = TRUE;
-		}
-		else if (event->key.keyval == GDK_Right) {
-			keys.BoolGDK_Right = TRUE;
-		}
-		else if (event->key.keyval == GDK_KP_Add) {
-			keys.BoolGDK_KP_Add = TRUE;
-		}
-		else if (event->key.keyval == GDK_KP_Subtract) {
-			keys.BoolGDK_KP_Subtract = TRUE;
-		}
-		else if (event->key.keyval == GDK_plus) {
-			keys.BoolGDK_plus = TRUE;
-		}
-		else if (event->key.keyval == GDK_minus) {
-			keys.BoolGDK_minus = TRUE;
-		}
-		// CTRL_A  ?
-		else if (event->key.state == 20 || event->key.state == 21) {
-			if (event->key.keyval == 65 || event->key.keyval == 97) {
-				keys.BoolGDK_Control_A = TRUE;
-			}
-		}
-		else if (event->key.keyval == GDK_space) {
-			keys.BoolGDK_space = TRUE;
-		}
-
-		if (keys.keyval == GDK_Control_L || keys.keyval == GDK_Control_R) {
-
-			// utils_puts_statusbar_global (_("Touche CTRL + Click gauche = selection verticale"));
-			// cdaudio_put_label_status_bar_cd (_INFO_, _SHOW_, _("Touche CTRL + Click gauche = selection verticale"));
-			// dvdaudio_puts_label_statusbar (_STATUSBAR_SAVE_, _("Touche CTRL inadaptee !"));
-		}
-		else if (keys.keyval == GDK_Shift_L || keys.keyval == GDK_Shift_R) {
-
-			// utils_puts_statusbar_global (_("Touche SHIFT + Click gauche = selection horizontale"));
-			// cdaudio_put_label_status_bar_cd (_INFO_, _SHOW_, _("Touche SHIFT + Click gauche = selection horizontale"));
-			// dvdaudio_puts_label_statusbar (_STATUSBAR_SAVE_, _("Touche SHIFT inadaptee !"));
-		}
-		else {
-			// utils_puts_statusbar_global ("");
-			// cdaudio_put_label_status_bar_cd (_INFO_, _SHOW_, "");
-			// dvdaudio_puts_label_statusbar (_STATUSBAR_RESTITUE_, "");
+	keys.BoolGDKPress = TRUE;
+	keys.keyval       = kevent->keyval;
+	
+	if( kevent->keyval == GDK_Control_L || kevent->keyval == GDK_Control_R ) {
+		keys.BoolGDK_Control_L_R = TRUE;
+	}		
+	else if( kevent->state == 20 || kevent->state == 21 ) {
+		if( kevent->keyval == 65 || kevent->keyval == 97 ) {
+			keys.BoolGDK_Control_A = TRUE;
 		}
 	}
-	else if (event->type == GDK_KEY_RELEASE) {
-		keys.eventkey           = GDK_KEY_RELEASE;
-		keys.type               = event->type;
-		keys.state              = 0;
-		keys.keyval             = 0;
-		keys.hardware_keycode   = 0;
-
-		if (event->key.keyval == GDK_Control_L) {
-			keys.BoolGDK_Control_L = FALSE;
+	
+	if( NOTEBOOK_POCHETTE == Config.NotebookGeneral ) {
+		if( kevent->keyval == GDK_Control_L || kevent->keyval == GDK_Control_R ) {
+			pochedir_set_ctrl( TRUE );
 		}
-		else if (event->key.keyval == GDK_Control_R) {
-			keys.BoolGDK_Control_R = FALSE;
-		}
-		else if (event->key.keyval == GDK_Shift_L) {
-			keys.BoolGDK_Shift_L = FALSE;
-		}
-		else if (event->key.keyval == GDK_Shift_R) {
-			keys.BoolGDK_Shift_R = FALSE;
-		}
-		else if (event->key.keyval == GDK_Left) {
-			keys.BoolGDK_Left = FALSE;
-		}
-		else if (event->key.keyval == GDK_Right) {
-			keys.BoolGDK_Right = FALSE;
-		}
-		else if (event->key.keyval == GDK_KP_Add) {
-			keys.BoolGDK_KP_Add = FALSE;
-		}
-		else if (event->key.keyval == GDK_KP_Subtract) {
-			keys.BoolGDK_KP_Subtract = FALSE;
-		}
-		else if (event->key.keyval == GDK_plus) {
-			keys.BoolGDK_plus = FALSE;
-		}
-		else if (event->key.keyval == GDK_minus) {
-			keys.BoolGDK_minus = FALSE;
-		}
-		keys.BoolGDK_space = FALSE;
-		keys.BoolGDK_Control_A = FALSE;
-
-		// utils_puts_statusbar_global ("");
-		// cdaudio_put_label_status_bar_cd (_INFO_, _SHOW_, "");
-		// dvdaudio_puts_label_statusbar (_STATUSBAR_RESTITUE_, "");
-	}
-	else if (keys.eventkey == GDK_KEY_RELEASE) {
-		keys.eventkey           = GDK_NOTHING;
-		keys.type               = event->type;
-		keys.state              = 0;
-		keys.keyval             = 0;
-		keys.hardware_keycode   = 0;
-
-		// utils_puts_statusbar_global ("");
-		// cdaudio_put_label_status_bar_cd (_INFO_, _SHOW_, "");
-		// dvdaudio_puts_label_statusbar (_STATUSBAR_RESTITUE_, "");
-
-	}
-	if (NOTEBOOK_SPLIT == Config.NotebookGeneral) {
-		if (GDK_KEY_PRESS == keys.eventkey) {
-			if (event->key.keyval == GDK_Delete) {
-				SplitSelector_cut ();
-			}
-			else if (event->key.keyval == GDK_space) {
-				// Une action sur la barre espace agit sur sur le play/pause
-				split_play ();
-			}
+		else if( kevent->keyval == GDK_Delete) {
+			// poche_remove_image();
 		}
 	}
+	else if( NOTEBOOK_SPLIT == Config.NotebookGeneral ) {
+		if( kevent->keyval == GDK_Delete ) {
+			SplitSelector_cut ();
+		}
+		else if( kevent->keyval == GDK_space ) {
+			// Une action sur la barre espace agit sur sur le play/pause
+			split_play ();
+		}
+	}
+
+	return FALSE;
+}
+// 
+// 
+gboolean on_wind_main_key_release_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )
+{
+	keys.BoolGDKPress        = FALSE;
+	keys.BoolGDK_Control_L_R = FALSE;
+	keys.BoolGDK_Control_A   = FALSE;
+	keys.keyval              = 0;
+	
+	if( NOTEBOOK_POCHETTE == Config.NotebookGeneral ) {
+		pochedir_set_ctrl( FALSE );
+	}
+	
 	return FALSE;
 }
 // 
@@ -500,38 +401,6 @@ void AnalyseCommandLine_set_argv (int argc, gchar *argv[])
 	g_free (str_current_dir);
 	str_current_dir = NULL;
 }
-/*
-void
-xcfa_init(int argc, char *argv[] )
-{
-	gint	 i;
-	gchar	*str_current_dir = NULL;
-	FILE	*fp = NULL;
-	
-	if (optind < argc) {
-		str_current_dir = g_get_current_dir ();
-		fp = fopen ("/home/cat/xcfa.txt", "a");
-		for (i = optind; i < argc; i++)
-		{
-			if (argv[i][0] == '/') {
-
-				fprintf (fp, "%s\n", argv[ i ]);
-			}
-			else {
-				gchar *str = NULL;
-				
-				str = g_strdup_printf ("%s/%s", str_current_dir, argv[i]);
-				fprintf (fp, "%s\n", str);
-				g_free (str);
-				str = NULL;
-			}
-		}
-		fclose (fp);
-	}
-	g_free (str_current_dir);
-	str_current_dir = NULL;
-}
-*/
 /* gint main (gint argc, gchar *argv[], gchar **envp)
  *
  * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable
@@ -547,14 +416,10 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gchar	*Path = NULL;
 	gchar	*PackageVersion = NULL;
 
-	// g_mem_set_vtable (glib_mem_profiler_table);
-	// xcfa_init(argc, &argv[0]);
 	
 	if (TRUE == process_exist_file ()) {
 		
 		AnalyseCommandLine_set_argv (argc, &argv[0]);		// Get and save param-file
-		// gtk_window_present (GTK_WINDOW (WindMain));
-		// gdk_notify_startup_complete ();
 		return (EXIT_SUCCESS);					// Quit process with success
 	}
 	else {
@@ -700,9 +565,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 
 	// POCHETTE
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_POCHETTE);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_pochette")), NOTEBOOK_POCHETTE_TEXTE);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_pochette")), NOTEBOOK_POCHETTE_TITRE);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_pochette")), NOTEBOOK_POCHETTE_IMAGE);
 
 	// SPLIT
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), NOTEBOOK_SPLIT);
@@ -732,7 +594,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_general")), Config.NotebookGeneral);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_expander_cd")), Config.NotebookExpanderCd);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_in_file")), Config.NotebookFile);
-	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_pochette")), Config.NotebookPochette);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_options")), Config.NotebookOptions);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_app_externes")), Config.NotebookAppExterns);
 	if (NOTEBOOK_SPLIT == Config.NotebookGeneral) {
@@ -746,13 +607,12 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	FileTags_set_flag_buttons ();
 	gtk_widget_set_sensitive (GTK_WIDGET (var_file_tags.Adr_table_tag), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_tag_appliquer")), FALSE);
-	pocheevnt_init ();
-	pochetimer_enable ();
 	
 	treeview_set_etat_fields ();
 	treeview_radiobutton_set_PosFieldsName ();
 	
 	filetrash_test_trash_is_ok ();
+	poche_set_flag_buttons();
 	
 	// SI CHARGEMENT DE FICHIERS DEPUIS LE BUREAU AVEC LE MENU CONTEXTUEL
 	process_goto_timeout ();
@@ -767,8 +627,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	
 	gtk_main ();
 	gdk_threads_leave ();
-	
-	// g_mem_profile ();
 
 	exit(EXIT_SUCCESS);
 }
