@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -138,6 +138,7 @@ NORMALISE normalise;
 
 // 
 // 
+/*
 GList *normalise_remove_glist (GList *p_list)
 {
 	GList     *List = NULL;
@@ -155,6 +156,7 @@ GList *normalise_remove_glist (GList *p_list)
 	p_list = NULL;
 	return ((GList *)NULL);
 }
+*/
 // 
 // 
 GList *normalise_remove_glist_STRUCT (GList *p_list)
@@ -214,6 +216,7 @@ GList *normalise_remove_glist_STRUCT (GList *p_list)
 }
 // 
 // 
+/*
 void normalise_print_DEBUG (GList *p_list)
 {
 	GList     *List = NULL;
@@ -228,6 +231,7 @@ void normalise_print_DEBUG (GList *p_list)
 		List = g_list_next(List);
 	}
 }
+*/
 // 
 // 
 void normalise_copy_wav_to_tmp (GList *p_list)
@@ -1623,13 +1627,8 @@ static void normalise_struct_lists (void *arg)
 // 
 static gint normalise_timeout (gpointer data)
 {
-	// if (WinNormReplay_is_get_close () == TRUE) {
-	// 	conv_stop_conversion ();
-	// 	normalise.bool_set_end_of_user = TRUE;
-	// }
 	if (TRUE == normalise.bool_etat) {
 		if (NULL != normalise.MessUser) {
-			// WinNormReplay_set_etat (normalise.MessUser);
 			g_print("normalise.MessUser = %s\n",normalise.MessUser);
 			g_free (normalise.MessUser);
 			normalise.MessUser = NULL;
@@ -1660,11 +1659,10 @@ static gint normalise_timeout (gpointer data)
 		WindScan_set_label (Str);
 	}
 	if (TRUE == conv.bool_percent_conv || TRUE == normalise.bool_pass_conv) {
-		normalise.total_percent = (double)((double)normalise.ElementActif + (double)conv.conversion_percent) / (double)normalise.NbrElementsInList;
-		// WinNormReplay_set_data_progressBar (normalise.total_percent);
 		
 		gchar	*Str = NULL;
 		
+		normalise.total_percent = (double)((double)normalise.ElementActif + (double)conv.conversion_percent) / (double)normalise.NbrElementsInList;
 		Str = g_strdup_printf ("%d%%", (int)(normalise.total_percent * 100));
 		WindScan_set_progress (Str, normalise.total_percent);
 		g_free (Str);
@@ -1686,7 +1684,6 @@ static gint normalise_timeout (gpointer data)
 					normalise.NbrElementsInList,
 					foo
 					);
-		// WinNormReplay_set_compteur (str);
 		g_free (str);
 		str = NULL;
 
@@ -1738,11 +1735,6 @@ static gint normalise_timeout (gpointer data)
 		gtk_timeout_remove (normalise.Handler_Timeout);
 		file_pixbuf_update_glist ();
 		fileaction_set_end (TYPE_NORMALISE);
-		if (FALSE == conv.bool_stop) {
-			NotifySend_msg (_("XCFA: Normalise fichiers"), _("Ok"));
-		} else {
-			NotifySend_msg (_("XCFA: Normalise fichiers"), _("Arret par l'utilisateur"));
-		}
 	}
 
 	return (TRUE);
@@ -1760,6 +1752,7 @@ void normalise_action (void)
 	normalise.bool_pass_conv = FALSE;
 	normalise.pass_conv = -1;
 	normalise.bool_etat = FALSE;
+	normalise.MessUser = NULL;
 	normalise.NbrElementsInList = 0;
 	normalise.ElementActif = 0;
 	conv_reset_struct (WindScan_close_request);
