@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -68,7 +68,65 @@ VAR_OPTIONS var_options;
 */
 
 
+// 
+// PARAMETRES POUR UNE ECOUTE MUSICALE EN FIN DE CONVERSION
+// 
+void on_checkbutton_end_of_convert_realize( GtkWidget *widget, gpointer user_data )
+{
+	var_options.Adr_checkbutton_end_of_convert = widget;
+	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(var_options.Adr_checkbutton_end_of_convert), Config.BoolCheckbuttonEndOfConvert );
+}
+// 
+// 
+void on_checkbutton_end_of_convert_clicked( GtkButton *button, gpointer user_data )
+{
+	Config.BoolCheckbuttonEndOfConvert = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(var_options.Adr_checkbutton_end_of_convert));
+}
+// 
+// 
+void on_button_music_file_end_of_convert_realize( GtkWidget *widget, gpointer user_data )
+{
+	var_options.Adr_button_music_file_end_of_convert = widget;
 
+	if( NULL != Config.FileMusicFileEndOfConvert && '\0' != *Config.FileMusicFileEndOfConvert ) {
+		gtk_button_set_label( GTK_BUTTON(var_options.Adr_button_music_file_end_of_convert), Config.FileMusicFileEndOfConvert );
+	}
+	else {
+		gtk_button_set_label( GTK_BUTTON(var_options.Adr_button_music_file_end_of_convert), Config.PathMusicFileEndOfConvert );
+	}
+}
+// 
+// 
+void options_choice_music( gchar *path )
+{
+	gchar	*Ptr = NULL;
+	
+	if( NULL != Config.PathMusicFileEndOfConvert ) {
+		g_free( Config.PathMusicFileEndOfConvert );
+		Config.PathMusicFileEndOfConvert = NULL;
+	}	
+	if( NULL != Config.FileMusicFileEndOfConvert ) {
+		g_free( Config.FileMusicFileEndOfConvert );
+		Config.FileMusicFileEndOfConvert = NULL;
+	}
+	Config.PathMusicFileEndOfConvert = g_strdup( path );
+	if( NULL != (Ptr = strrchr( Config.PathMusicFileEndOfConvert, '/'))) {
+		Ptr ++;
+		Config.FileMusicFileEndOfConvert = g_strdup( Ptr );
+		Ptr --;
+		*Ptr = '\0';
+		gtk_button_set_label( GTK_BUTTON(var_options.Adr_button_music_file_end_of_convert), Config.FileMusicFileEndOfConvert );
+	}
+}
+// 
+// 
+void on_button_music_file_end_of_convert_clicked( GtkButton *button, gpointer user_data )
+{
+	fileselect_create( _PATH_LOAD_FILE_MUSIC_, Config.PathMusicFileEndOfConvert, options_choice_music);
+}
+
+
+// 
 // INIT NICE
 // 
 void on_combobox_nice_realize (GtkWidget *widget, gpointer user_data)
