@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -77,12 +77,14 @@ void on_radiobutton_cdparanoia_mode_expert_realize (GtkWidget *widget, gpointer
 		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (var_options.Adr_radiobutton_cdparanoia_mode_expert), TRUE);
 }
 
-
+// 
 void on_entry_stockage_cdaudio_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_cd.Adr_entry_stockage_cdaudio = widget;
-	gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_stockage_cdaudio), Config.Templates_rep_cdaudio);
-	cdaudio_entry_stockage_cdaudio_changed ();
+	if( NULL != Config.Templates_rep_cdaudio ) {
+		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_stockage_cdaudio), Config.Templates_rep_cdaudio);
+		cdaudio_entry_stockage_cdaudio_changed ();
+	}
 }
 void on_entry_stockage_cdaudio_changed (GtkEditable *editable, gpointer user_data)
 {
@@ -92,8 +94,10 @@ void on_label_stockage_cdaudio_exemple_realize (GtkWidget *widget, gpointer user
 {
 	var_cd.Adr_label_stockage_cdaudio = widget;
 	if (var_cd.Adr_entry_stockage_cdaudio) {
-		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_stockage_cdaudio), Config.Templates_rep_cdaudio);
-		cdaudio_entry_stockage_cdaudio_changed ();
+		if( NULL != Config.Templates_rep_cdaudio ) {
+			gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_stockage_cdaudio), Config.Templates_rep_cdaudio);
+			cdaudio_entry_stockage_cdaudio_changed ();
+		}
 	}
 }
 
