@@ -50,7 +50,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -744,7 +744,8 @@ gchar *Parse_get_line (PARSE_TYPE p_ParseType, gint p_Num_cell)
 							// g_print ("NEW = %s\n", New );
 							g_string_free (gstr, TRUE);
 							gstr = g_string_new (NULL);
-							g_string_append_printf( gstr, New );
+							// g_string_append_printf( gstr, New );
+							g_string_append( gstr, New );
 							g_free( New );
 							New = NULL;
 							
