@@ -25,12 +25,12 @@
  */
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
 	#include <libintl.h>
-	#define _(String) gettext (String)
+	#define gettext_noop(x) (x)
 #endif
 
 #include <gtk/gtk.h>
@@ -73,12 +73,9 @@ enum
 
 VAR_PRGEXTERN var_prgextern;
 
-
-
 PRGINIT PrgInit;
 
 
-
 TABLEAU_PRG_EXTERN TableauPrgExtern [ NMR_MAX_TABLEAU ] = {
 
 {"a52dec",							// PACKAGEDEBIAN_64
@@ -89,7 +86,8 @@ TABLEAU_PRG_EXTERN TableauPrgExtern [ NMR_MAX_TABLEAU ] = {
 &PrgInit.bool_a52dec,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" liba52-0.7.4-dev",						// PAQUAGE
+gettext_noop(" Decode ATSC A/52 audio streams")},		// DESCRIPTION
 
 {"aacplusenc",							// PACKAGEDEBIAN_64
 "aacplusenc",							// PACKAGEDEBIAN_32
@@ -99,7 +97,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_aacplusenc,					// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" aacplusenc",							// PAQUAGE
+gettext_noop(" AAC+ encoder")},					// DESCRIPTION
 
 {"cdparanoia",							// PACKAGEDEBIAN_64
 "cdparanoia",							// PACKAGEDEBIAN_32
@@ -109,7 +108,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_cdparanoia,					// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" cdparanoia",							// PAQUAGE
+gettext_noop(" Extracteur cd audio")},				// DESCRIPTION
 
 {"checkmp3",							// PACKAGEDEBIAN_64
 "checkmp3",							// PACKAGEDEBIAN_32
@@ -119,27 +119,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_checkmp3,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
-{"imagemagick",							// PACKAGEDEBIAN_64
-"imagemagick",							// PACKAGEDEBIAN_32
-"convert",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_convert,						// FOUND
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
-{"cuetools",							// PACKAGEDEBIAN_64
-"cuetools",							// PACKAGEDEBIAN_32
-"cuebreakpoints",						// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_cuetools,						// FOUND
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" checkmp3",							// PAQUAGE
+gettext_noop(" Cherche des renseignements sur les formats mp3")},		// DESCRIPTION
 
 {"faac",							// PACKAGEDEBIAN_64
 "faac",								// PACKAGEDEBIAN_32
@@ -149,7 +130,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_faac,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" faac",							// PAQUAGE
+gettext_noop(" Audio Codeur freeware")},			// DESCRIPTION
 
 {"faad",							// PACKAGEDEBIAN_64
 "faad",								// PACKAGEDEBIAN_32
@@ -159,7 +141,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_faad,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" faad",							// PAQUAGE
+gettext_noop(" MPEG-4 AAC decodeur")},				// DESCRIPTION
 
 {"flac",							// PACKAGEDEBIAN_64
 "flac",								// PACKAGEDEBIAN_32
@@ -169,7 +152,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_flac,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" flac",							// PAQUAGE
+gettext_noop(" Conversion wav : flac")},			// DESCRIPTION
 
 {"icedax",							// PACKAGEDEBIAN_64
 "icedax",							// PACKAGEDEBIAN_32
@@ -179,7 +163,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_cdda2wav,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" icedax",							// PAQUAGE
+gettext_noop(" Extracteur cd audio")},				// DESCRIPTION
 
 {"lame",							// PACKAGEDEBIAN_64
 "lame",								// PACKAGEDEBIAN_32
@@ -189,7 +174,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_lame,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" lame",							// PAQUAGE
+gettext_noop(" Conversion wav : mp3")},				// DESCRIPTION
 
 {"lsdvd",							// PACKAGEDEBIAN_64
 "lsdvd",							// PACKAGEDEBIAN_32
@@ -199,7 +185,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_lsdvd,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" lsdvd",							// PAQUAGE
+gettext_noop(" Cherche les informations d'un dvd")},		// DESCRIPTION
 
 // ADD
 {"monkeys-audio",						// PACKAGEDEBIAN_64
@@ -210,7 +197,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_ape,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" monkeys-audio",						// PAQUAGE
+gettext_noop(" Monkey's Audio Console Front End : APE")},	// DESCRIPTION
 
 // ADD TO amd64 and i386
 {"musepack-tools",						// PACKAGEDEBIAN_64
@@ -221,7 +209,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_mpc123_mppdec,					// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" musepack-tools",						// PAQUAGE
+gettext_noop(" MusePack commandline utilities")},		// DESCRIPTION
 
 {"musepack-tools",						// PACKAGEDEBIAN_64
 "musepack-tools",						// PACKAGEDEBIAN_32
@@ -231,7 +220,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_mppenc,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" musepack-tools",						// PAQUAGE
+gettext_noop(" MusePack commandline utilities")},		// DESCRIPTION
 
 {"mplayer",							// PACKAGEDEBIAN_64
 "mplayer",							// PACKAGEDEBIAN_32
@@ -241,7 +231,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_mplayer,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" mplayer",							// PAQUAGE
+gettext_noop(" Lecteur et extracteur")},			// DESCRIPTION
 
 {"mp3gain",							// PACKAGEDEBIAN_64
 "mp3gain",							// PACKAGEDEBIAN_32
@@ -251,27 +242,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_mp3gain,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
-{"mpg321",							// PACKAGEDEBIAN_64
-"mpg321",							// PACKAGEDEBIAN_32
-"mpg321",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_mpg321,						// FOUND
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
-{"mp3splt",							// PACKAGEDEBIAN_64
-"mp3splt",							// PACKAGEDEBIAN_32
-"mp3splt",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_mp3splt,						// FOUND
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" mp3gain",							// PAQUAGE
+gettext_noop(" Normaliseur de fichier mp3")},			// DESCRIPTION
 
 {"normalize-audio",						// PACKAGEDEBIAN_64
 "normalize-audio",						// PACKAGEDEBIAN_32
@@ -281,7 +253,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_normalize,					// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" normalize-audio",						// PAQUAGE
+gettext_noop(" Normaliseur de fichier wav")},			// DESCRIPTION
 
 {"libnotify-bin",						// PACKAGEDEBIAN_64
 "libnotify-bin",						// PACKAGEDEBIAN_32
@@ -291,17 +264,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_notify_send,					// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
-{"ps2pdf",							// PACKAGEDEBIAN_64
-"ps2pdf",							// PACKAGEDEBIAN_32
-"ps2pdf",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_ps2pdf,						// FOUND
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" libnotify-bin",						// PAQUAGE
+gettext_noop(" A program to send desktop notifications")},	// DESCRIPTION
 
 {"shorten",							// PACKAGEDEBIAN_64
 "shorten",							// PACKAGEDEBIAN_32
@@ -311,7 +275,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_shorten,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" shorten",							// PAQUAGE
+gettext_noop(" Forte compression au format wave")},		// DESCRIPTION
 
 {"shntool",							// PACKAGEDEBIAN_64
 "shntool",							// PACKAGEDEBIAN_32
@@ -321,7 +286,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_shntool,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" shntool",							// PAQUAGE
+gettext_noop(" Decoupage de fichiers sans decodage")},		// DESCRIPTION
 
 {"sox",								// PACKAGEDEBIAN_64
 "sox",								// PACKAGEDEBIAN_32
@@ -331,7 +297,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_sox,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" sox",								// PAQUAGE
+gettext_noop(" Transformation universelle de fichiers son")},	// DESCRIPTION
 
 {"vorbis-tools",						// PACKAGEDEBIAN_64
 "vorbis-tools",							// PACKAGEDEBIAN_32
@@ -341,7 +308,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_oggenc,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" Vorbis-tools",						// PAQUAGE
+gettext_noop(" Conversion wav : ogg")},				// DESCRIPTION
 
 {"vorbisgain",							// PACKAGEDEBIAN_64
 "vorbisgain",							// PACKAGEDEBIAN_32
@@ -351,7 +319,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_vorbisgain,					// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" vorbisgain",							// PAQUAGE
+gettext_noop(" Normaliseur de fichier ogg")},			// DESCRIPTION
 
 {"wavsplit",							// PACKAGEDEBIAN_64
 "wavsplit",							// PACKAGEDEBIAN_32
@@ -361,7 +330,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_wavsplit,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
+" wavsplit",							// PAQUAGE
+gettext_noop(" Decoupage de fichiers sans decodage")},		// DESCRIPTION
 
 {"wavpack",							// PACKAGEDEBIAN_64
 "wavpack",							// PACKAGEDEBIAN_32
@@ -371,7 +341,8 @@ NULL},								// DESCRIPTION
 &PrgInit.bool_wavpack,						// FOUND
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
-NULL}								// DESCRIPTION
+" wavpack",							// PAQUAGE
+gettext_noop(" WAVPACK  Hybrid Lossless Audio Compressor")}	// DESCRIPTION
 
 };
 
@@ -453,7 +424,7 @@ gchar *prginit_get_Paquage (TYPE_PROGINIT TypeEnum)
 // 
 gchar *prginit_get_Description (TYPE_PROGINIT TypeEnum)
 {
-	return ((gchar *)TableauPrgExtern [ TypeEnum ] . Description);
+	return (gettext((gchar *)TableauPrgExtern [ TypeEnum ] . Description));
 }
 // 
 // 
@@ -557,16 +528,6 @@ void prginit_scan (void)
 			}
 		}
 				
-		// CAS: NMR_wXXcodecs
-		// 
-		// if (index == NMR_wXXcodecs) {
-		// 	if (HostConf.BoolCpuIs64Bits == TRUE) {
-		// 		TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name1;
-		// 	} else {
-		// 		TableauPrgExtern [ index ] . PtrName = TableauPrgExtern [ index ] .Name2;
-		// 	}
-		// }
-		
 		// FIXER LE PIXBUF SI PAS EN SELECTION
 		
 		if (*TableauPrgExtern [ index ] . BoolFound == TRUE)
@@ -589,8 +550,6 @@ gboolean prginit_get_etat (void)
 		PrgInit.bool_flac &
 		PrgInit.bool_lame &
 		PrgInit.bool_oggenc &
-		PrgInit.bool_mpg321 &
-		PrgInit.bool_ps2pdf &
 		PrgInit.bool_sox &
 		PrgInit.bool_normalize &
 		PrgInit.bool_checkmp3 &
@@ -598,18 +557,14 @@ gboolean prginit_get_etat (void)
 		PrgInit.bool_faac &
 		PrgInit.bool_mplayer &
 		PrgInit.bool_shorten &
-		PrgInit.bool_convert &
 		PrgInit.bool_wavpack &
 		PrgInit.bool_ape &
 		PrgInit.bool_lsdvd &
 		PrgInit.bool_vorbisgain &
 		PrgInit.bool_mp3gain &
-		PrgInit.bool_mp3splt &
 		PrgInit.bool_wavsplit &
 		PrgInit.bool_shntool &
-		PrgInit.bool_cuetools &
 		PrgInit.bool_aacplusenc;
-		// PrgInit.bool_notify_send;
 	
 	return (var_prgextern.Bool_Goto_Page_Options);
 
@@ -710,87 +665,6 @@ static void prginit_add_columns (GtkTreeView *treeview)
 	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
 	gtk_tree_view_append_column (treeview, column);
 }
-// 
-// 
-void prginit_remove_comment (void)
-{
-	gint	index;
-	
-	for (index = 0; index < NMR_MAX_TABLEAU; index ++) {
-		if (NULL != TableauPrgExtern[ index ].Description) {
-			g_free (TableauPrgExtern[ index ].Description);
-			TableauPrgExtern[ index ].Description = NULL;
-		}
-		if (NULL != TableauPrgExtern[ index ].Paquage) {
-			g_free (TableauPrgExtern[ index ].Paquage);
-			TableauPrgExtern[ index ].Paquage = NULL;
-		}
-	}
-}
-// 
-// 
-void prginit_init_comment (void)
-{
-	TableauPrgExtern[ NMR_a52dec ].Description 			= g_strdup (_(" Decode ATSC A/52 audio streams"));
-	TableauPrgExtern[ NMR_aacplusenc ].Description 			= g_strdup (_(" AAC+ encoder"));
-	TableauPrgExtern[ NMR_cdparanoia ].Description 			= g_strdup (_(" Extracteur cd audio"));
-	TableauPrgExtern[ NMR_checkmp3 ].Description 			= g_strdup (_(" Cherche des renseignements sur les formats mp3"));
-	TableauPrgExtern[ NMR_imagemagick_convert ].Description 	= g_strdup (_(" Manipulation de formats d'images"));
-	TableauPrgExtern[ NMR_cuetools ].Description 			= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_faac ].Description 			= g_strdup (_(" Audio Codeur freeware"));
-	TableauPrgExtern[ NMR_faad ].Description 			= g_strdup (_(" MPEG-4 AAC decodeur"));
-	TableauPrgExtern[ NMR_flac ].Description 			= g_strdup (_(" Conversion wav : flac / <b><i>METAFLAC > 1.1.2</i></b>"));
-	TableauPrgExtern[ NMR_icedax ].Description 			= g_strdup (_(" Extracteur cd audio"));
-	TableauPrgExtern[ NMR_lame ].Description 			= g_strdup (_(" Conversion wav : mp3"));
-	TableauPrgExtern[ NMR_lsdvd ].Description 			= g_strdup (_(" Cherche les informations d'un dvd"));
-	TableauPrgExtern[ NMR_mac ].Description 			= g_strdup (_(" Monkey's Audio Console Front End : APE"));
-	TableauPrgExtern[ NMR_musepack_tools_mppdec ].Description 	= g_strdup (_(" MusePack commandline utilities : mppdec"));
-	TableauPrgExtern[ NMR_musepack_tools_mppenc ].Description 	= g_strdup (_(" MusePack commandline utilities : mppenc"));
-	TableauPrgExtern[ NMR_mplayer ].Description 			= g_strdup (_(" Lecteur et extracteur"));
-	TableauPrgExtern[ NMR_mp3gain ].Description 			= g_strdup (_(" Normaliseur de fichier mp3"));
-	TableauPrgExtern[ NMR_mpg321 ].Description 			= g_strdup (_(" Conversion mp3 : wav"));
-	TableauPrgExtern[ NMR_mp3splt ].Description 			= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_normalize ].Description 			= g_strdup (_(" Normaliseur de fichier wav"));
-	TableauPrgExtern[ NMR_libnotify_bin ].Description 		= g_strdup (_(" A program to send desktop notifications"));
-	TableauPrgExtern[ NMR_ps2pdf ].Description 			= g_strdup (_(" Conversion  fichier  *.PS vers  *.PDF"));
-	TableauPrgExtern[ NMR_shorten ].Description 			= g_strdup (_(" Forte compression au format wave"));
-	TableauPrgExtern[ NMR_shntool ].Description			= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_sox ].Description 			= g_strdup (_(" Transformation universelle de fichiers son"));
-	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Description		= g_strdup (_(" Conversion wav : ogg"));
-	TableauPrgExtern[ NMR_vorbisgain ].Description 			= g_strdup (_(" Normaliseur de fichier ogg"));
-	TableauPrgExtern[ NMR_wavsplit ].Description 			= g_strdup (_(" Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_wavpack ].Description 			= g_strdup (_(" WAVPACK  Hybrid Lossless Audio Compressor"));
-
-	TableauPrgExtern[ NMR_a52dec ].Paquage 				= g_strdup (" liba52-0.7.4-dev");
-	TableauPrgExtern[ NMR_aacplusenc ].Paquage 			= g_strdup (" aacplusenc");
-	TableauPrgExtern[ NMR_cdparanoia ].Paquage 			= g_strdup (" cdparanoia");
-	TableauPrgExtern[ NMR_checkmp3 ].Paquage 			= g_strdup (" checkmp3");
-	TableauPrgExtern[ NMR_imagemagick_convert ].Paquage 		= g_strdup (" imagemagick");
-	TableauPrgExtern[ NMR_cuetools ].Paquage 			= g_strdup (" cuetools");
-	TableauPrgExtern[ NMR_faac ].Paquage 				= g_strdup (" faac");
-	TableauPrgExtern[ NMR_faad ].Paquage 				= g_strdup (" faad");
-	TableauPrgExtern[ NMR_flac ].Paquage 				= g_strdup (" flac");
-	TableauPrgExtern[ NMR_icedax ].Paquage 				= g_strdup (" icedax");
-	TableauPrgExtern[ NMR_lame ].Paquage 				= g_strdup (" lame");
-	TableauPrgExtern[ NMR_lsdvd ].Paquage 				= g_strdup (" lsdvd");
-	TableauPrgExtern[ NMR_mac ].Paquage 				= g_strdup (" monkeys-audio");
-	TableauPrgExtern[ NMR_musepack_tools_mppdec ].Paquage 		= g_strdup (" musepack-tools");
-	TableauPrgExtern[ NMR_musepack_tools_mppenc ].Paquage 		= g_strdup (" musepack-tools");
-	TableauPrgExtern[ NMR_mplayer ].Paquage 			= g_strdup (" mplayer");
-	TableauPrgExtern[ NMR_mp3gain ].Paquage 			= g_strdup (" mp3gain");
-	TableauPrgExtern[ NMR_mpg321 ].Paquage 				= g_strdup (" mpg321");
-	TableauPrgExtern[ NMR_mp3splt ].Paquage 			= g_strdup (" mp3splt");
-	TableauPrgExtern[ NMR_normalize ].Paquage 			= g_strdup (" normalize-audio");
-	TableauPrgExtern[ NMR_libnotify_bin ].Paquage 			= g_strdup (" libnotify-bin");
-	TableauPrgExtern[ NMR_ps2pdf ].Paquage 				= g_strdup (" ghostscript");
-	TableauPrgExtern[ NMR_shorten ].Paquage 			= g_strdup (" shorten");
-	TableauPrgExtern[ NMR_shntool ].Paquage				= g_strdup (" shntool");
-	TableauPrgExtern[ NMR_sox ].Paquage 				= g_strdup (" sox");
-	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Paquage		= g_strdup (" Vorbis-tools");
-	TableauPrgExtern[ NMR_vorbisgain ].Paquage 			= g_strdup (" vorbisgain");
-	TableauPrgExtern[ NMR_wavsplit ].Paquage 			= g_strdup (" wavsplit");
-	TableauPrgExtern[ NMR_wavpack ].Paquage 			= g_strdup (" wavpack");
-}
 // INITIALISATION DU SCROLLWINDOW
 // 
 void on_scrolledwindow_applications_externes_realize (GtkWidget *widget, gpointer user_data)
@@ -817,7 +691,6 @@ void on_scrolledwindow_applications_externes_realize (GtkWidget *widget, gpointe
 	g_object_unref (model);
 	gtk_container_add (GTK_CONTAINER (widget), treeview);
 	prginit_add_columns (GTK_TREE_VIEW (treeview));
-	prginit_init_comment ();
 	prginit_scan ();
 	prginit_print_info ();
 	gtk_widget_show_all (widget);
