@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -512,7 +512,7 @@ void split_maj_file_load (gchar *path)
 // 
 void on_button_importer_split_clicked (GtkButton *button, gpointer user_data)
 {
-	if (FALSE == keys.BoolGDK_space)
+	if (GDK_space != keys.keyval)
 		fileselect_create (_PATH_LOAD_SPLIT_FILE_, Config.PathLoadSplit, split_maj_file_load);
 }
 // INIT WIDGET DE LA DESTINAION DES DECOUPES
@@ -538,7 +538,7 @@ void split_maj_destination (gchar *path)
 // 
 void on_button_destination_split_clicked (GtkButton *button, gpointer user_data)
 {
-	if (FALSE == keys.BoolGDK_space) {
+	if (GDK_space != keys.keyval) {
 		fileselect_create (_PATH_CHOICE_DESTINATION_, Config.PathDestinationSplit, split_maj_destination);
 		split_set_flag_buttons ();
 	}
@@ -1116,7 +1116,7 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 	
 	// SCROLL
 	if( TRUE == BoolEventTypeScroll && VarSplit.NbrSelecteurs > 0 ) {
-		if( TRUE == keys.BoolGDK_Control_L || TRUE == keys.BoolGDK_Control_R ) {
+		if( TRUE == keys.BoolGDK_Control_L_R ) {
 			if (GDK_SCROLL_UP == EventTypeScrollDirection) {
 				page_plus_scrolled( CursorX );
 				gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
