@@ -1,33 +1,27 @@
  /*
- * file      : split.h
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : split.h
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -99,7 +93,7 @@
 
 #define CRAYON_BLEU_CLAIR_PLUS \
 	gdk_color.red = 0; \
-	gdk_color.green = 47000; \
+	gdk_color.green = 49000; \
 	gdk_color.blue = 65535; \
 	gdk_color_alloc (colormap, &gdk_color); \
 	gdk_gc_set_foreground (gc, &gdk_color);
@@ -143,13 +137,14 @@ typedef struct {								// DEFINITION D'UN POINT POUR LA LECTURE DU FICHIER WAV
 
 
 typedef struct {								// SPECIFICATION D'UN SELECTEUR
-	gint	Nmr;								// 
-	float	Begin;								// 
-	float	End;								// 
-	float	PercentBegin;							// 
-	float	PercentEnd;							// 
+	gint	Nmr;								// Numero du selecteur
+	float	BeginPaint;							// Position debut
+	float	EndPaint;							// Position fin
+	float	PercentBegin;							// Pourcentage debut
+	float	PercentEnd;							// Pourcentage fin
 } SELECTEUR;
 
+
 typedef enum {
 	_CURSOR_IS_NONE_ = 0,
 	_CURSOR_IS_LEFT_,
@@ -174,23 +169,16 @@ disques de bruitage...
 typedef struct {
 	GtkWidget		*AdrWidgetSpectre;				// Adr Widget Spectre
 	GtkWidget		*AdrWidgetSpectreChrono;			// Adr Widget Spectre Chrono
+	GtkWidget		*AdrWidgetSpectreTop;				// Adr Widget Spectre Chrono
 	
 	GtkButton		*Adr_button_destination;			// Adr du widget de la destinations des decoupes
 	
-	gint			ImgX, ImgY, ImgW, ImgH;				// Coordonnees reelle de l'image
-	gint			ChronoX, ChronoY, ChronoW, ChronoH;		// Coordonnees de la partie chrono
-	gint			SpectreTopX, SpectreTopY, SpectreTopW, SpectreTopH;
-	gint			SpectreX, SpectreY, SpectreW, SpectreH;		// Coordonnees du Spectre
-	
 	gint			NbrSelecteurs;					// Nombre total de selecteurs
 	SELECTEUR		Selecteur [ MAX_SELECTEURS_SPLIT +2 ];		// Tableau des selecteurs
 	gint			SelecteurActif;					// Le selecteur actif si NbrSelecteurs > -1
 	
 	gboolean		BoolReadFileSpectre;				// TRUE = BoolReadFileSpectre else NONE
 	
-	gint			NbrZoom;
-	gint			InitwidthZoom;
-	
 	gdouble			TimeSongSec;					// Duree totale du fichier en secondes
 	
 	void			(*FuncExternBegin) (gdouble Percent);		// Rappel modif pointeur DEBUT
@@ -230,19 +218,50 @@ typedef struct {
 	
 	gboolean		BoolQueueDrawSpectre;				// 
 	gboolean		BoolQueueDrawChrono;				// 
+	gboolean		BoolQueueDrawTop;				// 
+	GtkAdjustment		*AdjScroll;
 	
 	gboolean		BoolBlankWithCue;				// 
 	
 } VAR_SPLIT;
 
+
+#define VARSPLIT_CHRONO_X	( 0 )
+#define VARSPLIT_CHRONO_Y	( 0 )
+#define VARSPLIT_CHRONO_W	( VarSplit.AdrWidgetSpectreChrono->allocation.width - 1 )
+#define VARSPLIT_CHRONO_H	( VarSplit.AdrWidgetSpectreChrono->allocation.height - 1 )
+	
+#define VARSPLIT_SPECTRE_TOP_X	( 0 )
+#define VARSPLIT_SPECTRE_TOP_Y	( 0 )
+#define VARSPLIT_SPECTRE_TOP_W	( VarSplit.AdrWidgetSpectreTop->allocation.width - 1 )
+#define VARSPLIT_SPECTRE_TOP_H	( VarSplit.AdrWidgetSpectreTop->allocation.height - 1 )
+	
+#define VARSPLIT_SPECTRE_X	( 0 )
+#define VARSPLIT_SPECTRE_Y	( 0 )
+#define VARSPLIT_SPECTRE_W	( VarSplit.AdrWidgetSpectre->allocation.width - 1 )
+#define VARSPLIT_SPECTRE_H	( VarSplit.AdrWidgetSpectre->allocation.height - 1 )
+
+#define VARSPLIT_SPECTRE_WITH	( VarSplit.AdrWidgetSpectre->allocation.width )
+
+
+typedef struct {
+	gfloat	value;
+	gfloat	lower;
+	gfloat	upper;
+	gfloat	step_increment;
+	gfloat	page_size;
+	gfloat	page_increment;
+	gint	with;
+	gint	mul;
+} ADJUST;
+
 gboolean	SplitSpectre_read_file_spectre (gchar *PathNameFile);
 void		SplitSpectre_draw_lines (void);
 void		SplitSpectre_realize (GtkWidget *widget);
 void		split_draw (void);
-void		SplitSpectre_get_pos_widget (void);
-void		SplitSpectre_draw_chrono (void);
-void		SplitSpectre_draw_top (void);
-gint		SplitSpectre_get_with_scrollwindow (void);
+void		SplitSpectre_draw_chrono ( GtkWidget *widget );
+void		SplitSpectre_draw_top ( GtkWidget *widget );
+gint		SplitSpectre_get_with (void);
 void		SplitSpectre_remove (void);
 
 void		split_file_load_continue (gchar *p_PathNameFile);
