@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -160,6 +160,9 @@ void SplitSelector_cut (void)
 			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . EndPaint = -1;
 			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . PercentBegin =
 			VarSplit.Selecteur [ VarSplit.NbrSelecteurs ] . PercentEnd = 0.0;
+
+			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 		}
 	}
 }
