@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -773,13 +773,13 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 	
 	// ALL DATAS
 	// points * BLOCK_SIZE
-	g_print( "points(%d) * BLOCK_SIZE(%d) = \n\t%d octets\n\t%d Ko\n\t%d Mo\n\n",
+	/*g_print( "points(%d) * BLOCK_SIZE(%d) = \n\t%d octets\n\t%d Ko\n\t%d Mo\n\n",
 					points, 
 					BLOCK_SIZE, 
 					points * BLOCK_SIZE,
 					(points * BLOCK_SIZE) / 1024, 
 					((points * BLOCK_SIZE) / 1024) / 1024
-					 );
+					 );*/
 	
 	
 	// TODO: MARQUAGE DES PASSAGES BLANC SOIT < ~-50 dB
