@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -207,75 +207,6 @@ gchar *tags_get_time_wav (gchar *namefile)
 }
 // 
 // 
-typedef struct {
-	gint   num;
-	gchar *name;
-} STRUCT_TAGS_CD;
-// 
-// 
-STRUCT_TAGS_CD StructTagsCD []= {
-{0,	"unknown"},	// 12
-{1,	"blues"},	// 00
-{2,	"classical"},	// 32
-{3,	"country"},	// 02
-{4,	"data"},	// 12
-{5,	"folk"},	// 80
-{6,	"jazz"},	// 08
-{7,	"misc"},	// 12
-{8,	"newage"},	// 10
-{9,	"reggae"},	// 16
-{10,	"rock"},	// 17
-{11,	"soundtrack"},	// 24
-{-1,	NULL}
-};
-// 
-// 
-gint tags_get_StructTagsCD_to_StructTagsFileMp3 (gint NumCD)
-{
-	switch (NumCD) {
-	case 0 :  return (12);		// 00 - unknown		->	12 - Other
-	case 1 :  return (0);		// 01 - blues		->	00 - Blues
-	case 2 :  return (32);		// 02 - classical	->	32 - Classical
-	case 3 :  return (2);		// 03 - country		->	02 - Country
-	case 4 :  return (12);		// 04 - data		->	12 - Other
-	case 5 :  return (80);		// 05 - folk		->	80 - Folk
-	case 6 :  return (8);		// 06 - jazz		->	08 - Jazz
-	case 7 :  return (12);		// 07 - misc		->	12 - Other
-	case 8 :  return (10);		// 08 - newage		->	10 - New Age
-	case 9 :  return (16);		// 09 - reggae		->	16 - Reggae
-	case 10 : return (17);		// 10 - rock		->	17 - Rock
-	case 11 : return (24);		// 11 - soundtrack	->	24 - Soundtrack
-	}
-	return (12);
-}
-// 
-// 
-void tags_set_elements_comboboxCD (GtkWidget *widget)
-{
-	gint i;
-	
-	for (i=0; StructTagsCD[ i ].num != -1; i++)
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), StructTagsCD [ i ].name);
-	
-}
-// 
-// 
-gint tags_get_num_comboboxCD (gint value)
-{
-	return (StructTagsCD [ value ].num);
-}
-// 
-// 
-gint tags_get_elements_comboboxCD (gint num)
-{
-	gint i;
-	
-	for (i=0; StructTagsCD [ i ].num != num; i++);
-	
-	if (i > 11) i = 0;
-
-	return (i);
-}
 // 
 // 
 typedef struct {
@@ -437,200 +368,6 @@ STRUCT_TAGS_FILE_MP3 StructTagsFileMp3 [] = {
 {102, "Chanson française"},
 {-1,  NULL}
 };
-/*
-00 - Blues
-01 - Classic Rock
-02 - Country
-03 - Dance
-04 - Disco
-05 - Funk
-06 - Grunge
-07 - Hip-Hop
-08 - Jazz
-09 - Metal
-10 - New Age
-11 - Oldies
-12 - Other
-13 - Pop
-14 - R&B
-15 - Rap
-16 - Reggae
-17 - Rock
-18 - Techno
-19 - Industrial
-20 - Alternative
-21 - Ska
-22 - Death Metal
-23 - Pranks
-24 - Soundtrack
-25 - Euro-Techno
-26 - Ambient
-27 - Trip-Hop
-28 - Vocal
-29 - Jazz+Funk
-30 - Fusion
-31 - Trance
-32 - Classical
-33 - Instrumental
-34 - Acid
-35 - House
-36 - Game
-37 - Sound Clip
-38 - Gospel
-39 - Noise
-40 - Alternative Rock
-41 - Bass
-43 - Punk
-44 - Space
-45 - Meditative
-46 - Instrumental Pop
-47 - Instrumental Rock
-48 - Ethnic
-49 - Gothic
-50 - Darkwave
-51 - Techno-Industrial
-52 - Electronic
-53 - Pop-Folk
-54 - Eurodance
-55 - Dream
-56 - Southern Rock
-57 - Comedy
-58 - Cult
-59 - Gangsta
-60 - Top 40
-61 - Christian Rap
-62 - Pop/Funk
-63 - Jungle
-64 - Native US
-65 - Cabaret
-66 - New Wave
-67 - Psychedelic
-68 - Rave
-69 - Showtunes
-70 - Trailer
-71 - Lo-Fi
-72 - Tribal
-73 - Acid Punk
-74 - Acid Jazz
-75 - Polka
-76 - Retro
-77 - Musical
-78 - Rock & Roll
-79 - Hard Rock
-80 - Folk
-81 - Folk-Rock
-82 - National Folk
-83 - Swing
-84 - Fast Fusion
-85 - Bebob
-86 - Latin
-87 - Revival
-88 - Celtic
-89 - Bluegrass
-90 - Avantgarde
-91 - Gothic Rock
-92 - Progressive Rock
-93 - Psychedelic Rock
-94 - Symphonic Rock
-95 - Slow Rock
-96 - Big Band
-97 - Chorus
-98 - Easy Listening
-99 - Acoustic
-100 - Humour
-101 - Speech
-102 - Chanson
-103 - Opera
-104 - Chamber Music
-105 - Sonata
-106 - Symphony
-107 - Booty Bass
-108 - Primus
-109 - Porn Groove
-110 - Satire
-111 - Slow Jam
-112 - Club
-113 - Tango
-114 - Samba
-115 - Folklore
-116 - Ballad
-117 - Power Ballad
-118 - Rhythmic Soul
-119 - Freestyle
-120 - Duet
-121 - Punk Rock
-122 - Drum Solo
-123 - A Cappella
-124 - Euro-House
-125 - Dance Hall
-126 - Goa
-127 - Drum & Bass
-128 - Club-House
-129 - Hardcore
-130 - Terror
-131 - Indie
-132 - BritPop
-133 - Negerpunk
-134 - Polsk Punk
-135 - Beat
-136 - Christian Gangsta
-137 - Heavy Metal
-138 - Black Metal
-139 - Crossover
-140 - Contemporary Christian
-141 - Christian Rock
-142 - Merengue
-143 - Salsa
-144 - Thrash Metal
-145 - Anime
-146 - JPop
-147 - SynthPop
-*/
-// 
-// 
-gint tags_get_active (gint Num)
-{
-	gint	Cpt;
-	gint	Number = 0;
-	
-	for (Cpt = 0; StructTagsFileMp3[ Cpt ].num > -1; Cpt ++) {
-		if (StructTagsFileMp3[ Cpt ].num == Num) {
-			break;
-		}
-		Number ++;
-	}
-	return (Number);
-}
-// 
-// 
-/*
-gint OLD_tags_get_genre_by_value (gchar *name)
-{
-	gint	 i;
-	gchar	 NewName [ 100 ];
-	gchar	*PtrNewName = NewName;
-		
-	if (NULL == name || '\0' == *name) return (-1);
-	
-	strcpy (NewName, name);
-
-	while (*PtrNewName) {
-		// if (*PtrNewName == ' ') {
-		if (g_ascii_isspace(*PtrNewName)) {
-			PtrNewName ++;
-			continue;
-		}
-		if (g_ascii_isalpha(*PtrNewName) == FALSE) break;
-		PtrNewName ++;
-	}
-	*PtrNewName = '\0';
-
-	for (i=0; StructTagsFileMp3[ i ].num != -1; i++)
-		if (strncmp (StructTagsFileMp3[ i ].name, NewName, strlen (NewName)) == 0) return (StructTagsFileMp3[ i ].num);
-	
-	return (-1);
-}
-*/
 // 
 // 
 gint tags_get_genre_by_value (gchar *name)
