@@ -26,7 +26,7 @@
  
  
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -50,7 +50,6 @@
 
 #include "global.h"
 #include "get_info.h"
-#include "file.h"
 #include "tags.h"
 #include <taglib/tag_c.h>
 
