@@ -26,7 +26,7 @@
  
  
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -49,14 +49,13 @@
 #endif
 
 #include "global.h"
-#include "file.h"
 #include "tags.h"
 
 
 
 // 
 // 
-void tagswav_close_file (WAVE *son)
+void tagswav_close_file( WAVE *son )
 {
 	if (NULL != son->file) {
 		fclose(son->file);  
@@ -122,8 +121,9 @@ gboolean tagswav_read_file (gchar *wave_file, WAVE *son)
 	// FICHIER WAV ?
 	if ((0 != strncmp (son->RIFF.ChunkID, "RIFF", 4)) || (0 != strncmp (son->RIFF.Format, "WAVE", 4)) || (0 != strncmp (son->FMT.Subchunk1ID, "fmt ", 4))) {
 		g_print ("%s  n'est pas un fichier wav\n", wave_file);  
-		fclose(son->file);  
-		son->file = NULL;
+		// fclose(son->file);  
+		// son->file = NULL;
+		tagswav_close_file( son );
 		return (FALSE);
 	}
 	
@@ -199,8 +199,9 @@ gboolean tagswav_read_file (gchar *wave_file, WAVE *son)
  	}
 	else if (FALSE == BoolFound)  {
 		// fermeture du fichier  
-		fclose (son->file);  
- 		son->file = NULL;
+		// fclose (son->file);  
+ 		// son->file = NULL;
+ 		tagswav_close_file( son );
 	}
 
 	return BoolFound;  
@@ -232,7 +233,7 @@ gboolean tagswav_file_is_mono (gchar *namefile)
 	WAVE	son;
 	
 	if (TRUE == tagswav_read_file (namefile, &son)) {
-		tagswav_close_file (&son);
+		tagswav_close_file( &son );
 		return (son.FMT.NumChannels == 1 ? TRUE : FALSE);
 	}
 	return (FALSE);
@@ -244,7 +245,7 @@ gboolean tagswav_file_GetBitrate (gchar *namefile, gint *Channels, gint *Hertz,
 	WAVE	 	son;
 	
 	if (TRUE == tagswav_read_file (namefile, &son)) {
-		tagswav_close_file (&son);
+		tagswav_close_file( &son );
 		if (Channels)	*Channels = son.FMT.NumChannels;
 		if (Hertz)	*Hertz    = son.FMT.SampleRate;
 		if (Bits)	*Bits     = son.FMT.BitsPerSample;
@@ -276,7 +277,7 @@ INFO_WAV *tagswav_get_info (gchar *namefile)
 	}
 
 	BoolReadWavFile = tagswav_read_file (namefile, &son);
-	tagswav_close_file (&son);
+	tagswav_close_file( &son );
 	
 	if (FALSE == BoolReadWavFile) {
 		g_free (ptrinfo);
@@ -297,9 +298,6 @@ INFO_WAV *tagswav_get_info (gchar *namefile)
 	sec = son.DATA.Subchunk2Size / son.FMT.ByteRate;
 	ptrinfo->SecTime              = sec;
 	ptrinfo->ValueMark.SecTime    = sec;
-	// ptrinfo->ValueMark.ValueMarkA = 0.0;
-	// ptrinfo->ValueMark.ValueMarkB = 100.0;
-	// ptrinfo->ValueMark.Value      = 0.0;
 
 	s = sec % 60; sec /= 60;
 	m = sec % 60; sec /= 60;
@@ -321,7 +319,6 @@ INFO_WAV *tagswav_get_info (gchar *namefile)
 	ptrinfo->BoolConv= FALSE;
 
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
-	// tags_set (detail->namefile, ptrinfo->tags);
 	tags_set (namefile, ptrinfo->tags);
 	
 	ptrinfo->LevelDbfs.level = -1;
@@ -339,7 +336,7 @@ gint tagswav_get_time_sec (gchar *namefile)
 	// PRINT_FUNC_LF();
 	
 	if (TRUE == tagswav_read_file (namefile, &son)) {
-		tagswav_close_file (&son);
+		tagswav_close_file( &son );
 		return (son.DATA.Subchunk2Size / son.FMT.ByteRate);
 	}
 	return (0);
