@@ -26,7 +26,7 @@
  
  
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -149,38 +149,39 @@ TRANS trans[] = {
 { _("Le resultat du Split sera dirige vers 'Destination des fichiers'.") },
 { _("Split") },
 { _(" Split ") },
-{ _("Recto") },
-{ _("Verso") },
-{ _("Effacer") },
-{ _("<b> Choix images </b>") },
-{ _("<b>label</b>") },
-{ _("<b> Voir / Avec </b>") },
-{ _("<b> Chemin et generation  PostScript / pdf </b>") },
-{ _("<b> Titre du CD </b>") },
-{ _("Recupere depuis le web des images selon le critere indique depuis 'Titre du CD'. Le stockage se fait dans 'Emplacement des images Web'") },
-{ _("<b> Web </b>") },
-{ _("<b> Titre cd </b>") },
-{ _("<b> Recto % </b>") },
-{ _("<b> Verso % </b>") },
-{ _("<b> Emplacement des images Web </b>") },
-{ _(" Image ") },
-{ _("<b> Titre </b>") },
-{ _("<b> Pied de page </b>") },
-{ _(" Titre ") },
-{ _("<b> Recto </b>") },
-{ _("<b> Verso </b>") },
-{ _("<b> Relier les champs </b>") },
-{ _("de la liste") },
-{ _("<b> Numerotation </b>") },
-{ _("Titres cd") },
-{ _("<b> Importation </b>") },
-{ _("<b> Texte pochette </b>") },
-{ _(" Texte ") },
+{ _("Importation du titre du CD.") },
+{ _("<b>Titre CD</b>") },
+{ _("Choix d'une nouvelle police.") },
+{ _("Texte gras.") },
+{ _("Texte italique.") },
+{ _("Ajouter du texte editable.") },
+{ _("<b>Texte</b>") },
+{ _("Saisissez ici un critere de recherche d'images.") },
+{ _("Importation des images depuis le Web.") },
+{ _("<b>Import images web</b>") },
+{ _("Supprimer l'image en selection") },
+{ _("AJouter de nouvelles images.") },
+{ _("Ouvre un fichier") },
+{ _("Enregistrer la page au format png.") },
+{ _("Sauvegarde le fichier") },
+{ _("Diminution de l'echelle.") },
+{ _("Reduit l'agrandissement") },
+{ _("Echelle a 100%.") },
+{ _("Remet l'echelle a 100%") },
+{ _("Augmentation de l'echelle.") },
+{ _("Augmente l'agrandissement") },
+{ _("Echelle compatible avec la taille de la fenetre.") },
+{ _("Adapte l'echelle a la taille de la fenetre") },
+{ _("Emplacement de sauvegarde des fichiers.") },
+{ _("Nom (sans extention)  du fichier a sauvegarder.") },
+{ _("label") },
 { _(" Pochette ") },
 { _("Nice") },
 { _(" <b>Priorite systeme</b> ") },
 { _("<i><b>Indiquez</b> ici le dossier sur votre systeme qui servira de lieu\nde stockage provisoire pendant les differentes conversions.</i>\n") },
 { _(" <b>Dossier provisoire des conversions</b> ") },
+{ _("button") },
+{ _(" <b>Jouer une musique en fin de tache</b> ") },
 { _(" General ") },
 { _("cdparanoia") },
 { _("cdda2wav / icedax") },
@@ -456,7 +457,6 @@ TRANS trans[] = {
 };
 
 
-
 	if (*trans [ 0 ] . string);
 }
 
