@@ -25,8 +25,8 @@
  */
 
 
-#ifndef _treeview_h
-#define _treeview_h 1
+#ifndef treeview_h
+#define treeview_h 1
 
 
 void		treeview_open_window (void);
