@@ -26,7 +26,7 @@
  
  
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -134,7 +134,8 @@ gboolean WindScan_open (gchar *title, TYPE_PROGRESS TypeProgress)
 	
 	VarWindScan.CloseByUser = FALSE;
 	VarWindScan.close_request = FALSE;
-	
+	// PRINT("------------------------------------------------------------");
+	// g_print( "VarWindScan.IsShow = %s\n", VarWindScan.IsShow ? "TRUE" : "FALSE" );
 	if (TRUE == VarWindScan.IsShow) {
 		gdk_window_raise (VarWindScan.AdrWin->window);
 	}
@@ -165,7 +166,7 @@ gboolean WindScan_open (gchar *title, TYPE_PROGRESS TypeProgress)
 		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (VarWindScan.AdrProgressBar), _("Waiting ..."));
 	}
 	
-	VarWindScan.HandlerTimeout = gtk_timeout_add (50, WindScan_timeout, 0);
+	VarWindScan.HandlerTimeout = gtk_timeout_add (100, WindScan_timeout, 0);
 	
 	return (BoolIsShow);
 }
